@@ -10,15 +10,16 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
 # standard libraries
+import os
 import logging
+import time
 from logging.handlers import RotatingFileHandler
 import datetime
-from dateutil.tz import tzutc
 import sys
 
 # external packages
@@ -36,7 +37,6 @@ class LoggerWriter:
         self.standard = std
 
     def write(self, message):
-        self.standard.write(message)
         first = True
         for line in message.rstrip().splitlines():
             if first:
@@ -49,10 +49,6 @@ class LoggerWriter:
         pass
 
 
-def timeTz(*args):
-    return datetime.datetime.now(tzutc()).timetuple()
-
-
 def addLoggingLevel(levelName, levelNum, methodName=None):
     """
     Comprehensively adds a new logging level to the `logging` module and the
@@ -88,13 +84,10 @@ def addLoggingLevel(levelName, levelNum, methodName=None):
     """
     if not methodName:
         methodName = levelName.lower()
-
     if hasattr(logging, levelName):
         return
-
     if hasattr(logging, methodName):
         return
-
     if hasattr(logging.getLoggerClass(), methodName):
         return
 
@@ -107,16 +100,29 @@ def addLoggingLevel(levelName, levelNum, methodName=None):
     setattr(logging.getLoggerClass(), methodName, logForLevel)
 
 
-def setupLogging():
+def redirectSTD():
+    """
+    :return:
+    """
+    # transfer all sys outputs to logging
+    sys.stderr = LoggerWriter(logging.getLogger().error, 'STDERR', sys.stderr)
+    sys.stdout = LoggerWriter(logging.getLogger().info, 'STDOUT', sys.stdout)
+    return True
+
+
+def setupLogging(redirect=True):
     """
     setupLogging defines the logger and formats and disables unnecessary
     library logging
 
     :return: true for test purpose
     """
-    logging.Formatter.converter = timeTz
-    timeTag = datetime.datetime.now(datetime.timezone.utc).strftime('%Y-%m-%d')
-    logFile = f'mw4-{timeTag}.log'
+    if not os.path.isdir('./log'):
+        os.mkdir('./log')
+
+    logging.Formatter.converter = time.gmtime
+    timeTag = datetime.datetime.utcnow().strftime('%Y-%m-%d')
+    logFile = f'./log/mw4-{timeTag}.log'
     logHandler = RotatingFileHandler(logFile, mode='a', maxBytes=100 * 1024 * 1024,
                                      backupCount=100, encoding=None, delay=False)
     logging.basicConfig(level=logging.DEBUG,
@@ -134,15 +140,13 @@ def setupLogging():
     logging.getLogger('PyQt5').setLevel(logging.WARNING)
     logging.getLogger('requests').setLevel(logging.WARNING)
     logging.getLogger('urllib3').setLevel(logging.WARNING)
-    logging.getLogger('matplotlib').setLevel(logging.WARNING)
     logging.getLogger('astropy').setLevel(logging.WARNING)
     logging.getLogger('keyring').setLevel(logging.WARNING)
     addLoggingLevel('HEADER', 55)
     addLoggingLevel('UI', 35)
     addLoggingLevel('TRACE', 5)
-    # transfer all sys outputs to logging
-    sys.stderr = LoggerWriter(logging.getLogger().error, 'STDERR', sys.stderr)
-    # sys.stdout = LoggerWriter(logging.getLogger().info, 'STDOUT', sys.stdout)
+    if redirect:
+        redirectSTD()
     return True
 
 
