@@ -10,24 +10,24 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
 import platform
-from distutils.version import StrictVersion
+from packaging.utils import Version
 
 excludedPlatforms = ['armv7l', 'aarch64']
 isAvailable = platform.machine() not in excludedPlatforms
 isAnalyse = False
-isColor = True
+isReference = False
 isWindows = platform.system() == 'Windows'
 isLinux = platform.system() == 'Linux'
 isMac = platform.system() == 'Darwin'
 
 
 def checkAutomation():
-    verResult = StrictVersion('3.8.2') <= StrictVersion(platform.python_version())
+    verResult = Version('3.8.2') <= Version(platform.python_version())
     winResult = platform.system() == 'Windows'
     result = verResult and winResult
     return result
