@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -22,7 +22,8 @@ import time
 
 # external packages
 from PyQt5.QtCore import Qt
-from PyQt5.QtWidgets import QWidget
+from PyQt5.QtGui import QTransform
+from skyfield.almanac import dark_twilight_day, TWILIGHTS
 
 # local import
 if packageConfig.isAvailable:
@@ -38,11 +39,17 @@ from gui.extWindows.measureW import MeasureWindow
 from gui.extWindows.imageW import ImageWindow
 from gui.extWindows.satelliteW import SatelliteWindow
 from gui.extWindows.analyseW import AnalyseWindow
+from gui.extWindows.videoW1 import VideoWindow1
+from gui.extWindows.videoW2 import VideoWindow2
+from gui.extWindows.videoW3 import VideoWindow3
+from gui.extWindows.videoW4 import VideoWindow4
+from gui.extWindows.bigPopupW import BigPopup
 from gui.widgets.main_ui import Ui_MainWindow
 from gui.mainWmixin.tabMount import Mount
 from gui.mainWmixin.tabEnviron import Environ
 from gui.mainWmixin.tabAlmanac import Almanac
 from gui.mainWmixin.tabModel import Model
+from gui.mainWmixin.runBasic import BasicRun
 from gui.mainWmixin.tabBuildPoints import BuildPoints
 from gui.mainWmixin.tabManageModel import ManageModel
 from gui.mainWmixin.tabSatSearch import SatSearch
@@ -50,15 +57,17 @@ from gui.mainWmixin.tabSatTrack import SatTrack
 from gui.mainWmixin.tabMinorPlanetTime import MinorPlanetTime
 from gui.mainWmixin.tabRelay import Relay
 from gui.mainWmixin.tabTools import Tools
+from gui.mainWmixin.tabAnalysis import Analysis
 from gui.mainWmixin.tabPower import Power
 from gui.mainWmixin.tabSettDevice import SettDevice
 from gui.mainWmixin.tabSettMount import SettMount
-from gui.mainWmixin.tabSettHorizon import SettHorizon
 from gui.mainWmixin.tabSettImaging import SettImaging
+from gui.mainWmixin.tabSettImageStats import SettImageStats
 from gui.mainWmixin.tabSettDome import SettDome
 from gui.mainWmixin.tabSettParkPos import SettParkPos
 from gui.mainWmixin.tabSettRelay import SettRelay
 from gui.mainWmixin.tabSettMisc import SettMisc
+from logic.profiles.profile import loadProfile, saveProfile, blendProfile
 
 
 class MainWindow(
@@ -68,6 +77,7 @@ class MainWindow(
     Environ,
     Almanac,
     Model,
+    BasicRun,
     BuildPoints,
     ManageModel,
     SatSearch,
@@ -76,10 +86,11 @@ class MainWindow(
     Relay,
     Power,
     Tools,
+    Analysis,
     SettDevice,
     SettMount,
-    SettHorizon,
     SettImaging,
+    SettImageStats,
     SettDome,
     SettParkPos,
     SettRelay,
@@ -87,7 +98,7 @@ class MainWindow(
     """
     the main window class handles the main menu as well as the show and no show
     part of any other window. all necessary processing for functions of that gui
-    will be linked to this class. therefore window classes will have a threadpool
+    will be linked to this class. therefore, window classes will have a threadpool
     for managing async processing if needed.
     """
 
@@ -100,13 +111,15 @@ class MainWindow(
         Styles.colorSet = colSet
         super().__init__()
         self.app = app
+        self.msg = app.msg
         self.threadPool = app.threadPool
         self.deviceStat = app.deviceStat
         self.uiWindows = app.uiWindows
         self.setAttribute(Qt.WA_DeleteOnClose)
         self.ui = Ui_MainWindow()
         self.ui.setupUi(self)
-        self.closing = False
+        self.satStatus = False
+        self.gameControllerRunning = False
         self.setWindowTitle(f'MountWizzard4 - v{self.app.__version__}')
 
         self.uiWindows['showMessageW'] = {
@@ -145,6 +158,30 @@ class MainWindow(
             'name': 'AnalyseDialog',
             'class': AnalyseWindow,
         }
+        self.uiWindows['showVideoW1'] = {
+            'button': self.ui.openV1,
+            'classObj': None,
+            'name': 'Video1',
+            'class': VideoWindow1,
+        }
+        self.uiWindows['showVideoW2'] = {
+            'button': self.ui.openV2,
+            'classObj': None,
+            'name': 'Video2',
+            'class': VideoWindow2,
+        }
+        self.uiWindows['showVideoW3'] = {
+            'button': self.ui.openV3,
+            'classObj': None,
+            'name': 'Video3',
+            'class': VideoWindow3,
+        }
+        self.uiWindows['showVideoW4'] = {
+            'button': self.ui.openV4,
+            'classObj': None,
+            'name': 'Video4',
+            'class': VideoWindow4,
+        }
         if packageConfig.isAvailable:
             self.uiWindows['showSimulatorW'] = {
                 'button': self.ui.mountConnected,
@@ -158,69 +195,54 @@ class MainWindow(
             'name': 'KeypadDialog',
             'class': KeypadWindow,
         }
+        self.uiWindows['showBigPopupW'] = {
+            'button': self.ui.big,
+            'classObj': None,
+            'name': 'BigPopup',
+            'class': BigPopup,
+        }
         self.deviceStatGui = {
             'dome': self.ui.domeConnected,
             'camera': self.ui.cameraConnected,
-            'environOverall': self.ui.environConnected,
-            'astrometry': self.ui.astrometryConnected,
+            'refraction': self.ui.refractionConnected,
+            'plateSolve': self.ui.plateSolveConnected,
             'mount': self.ui.mountConnected,
         }
         self.mwSuper('__init__')
-
-        self.modelPositionPlot = self.embedMatplot(self.ui.modelPosition)
-        self.modelPositionPlot.figure.canvas.mpl_connect(
-            'button_press_event', self.onMouseEdit
-        )
-        self.errorAscendingPlot = self.embedMatplot(self.ui.errorAscending)
-        self.errorDistributionPlot = self.embedMatplot(self.ui.errorDistribution)
-        self.twilight = self.embedMatplot(self.ui.twilight)
-
         self.app.mount.signals.pointDone.connect(self.updateStatusGUI)
         self.app.mount.signals.mountUp.connect(self.updateMountConnStat)
         self.app.mount.signals.settingDone.connect(self.updateMountWeatherStat)
         self.app.remoteCommand.connect(self.remoteCommand)
-        self.app.astrometry.signals.message.connect(self.updateAstrometryStatus)
+        self.app.plateSolve.signals.message.connect(self.updatePlateSolveStatus)
         self.app.dome.signals.message.connect(self.updateDomeStatus)
         self.app.camera.signals.message.connect(self.updateCameraStatus)
         self.ui.saveConfigQuit.clicked.connect(self.quitSave)
-        self.ui.loadFrom.clicked.connect(self.loadProfile)
-        self.ui.saveConfigAs.clicked.connect(self.saveProfileAs)
-        self.ui.saveConfig.clicked.connect(self.saveProfile)
+        self.ui.loadFrom.clicked.connect(self.loadProfileGUI)
+        self.ui.addFrom.clicked.connect(self.addProfileGUI)
+        self.ui.saveConfigAs.clicked.connect(self.saveConfigAs)
+        self.ui.saveConfig.clicked.connect(self.saveConfig)
+        self.app.seeingWeather.b = self.ui.label_b.property('a')
 
         for window in self.uiWindows:
             self.uiWindows[window]['button'].clicked.connect(self.toggleWindow)
 
         self.initConfig()
         self.ui.colorSet.currentIndexChanged.connect(self.refreshColorSet)
+        self.ui.collectWindows.clicked.connect(self.collectWindows)
         self.showExtendedWindows()
+        self.activateWindow()
 
+        self.ui.tabsMovable.clicked.connect(self.enableTabsMovable)
         self.app.update1s.connect(self.updateTime)
+        self.app.update1s.connect(self.updateControllerStatus)
+        self.app.update1s.connect(self.updateThreadAndOnlineStatus)
         self.app.update1s.connect(self.updateWindowsStats)
         self.app.update1s.connect(self.smartFunctionGui)
         self.app.update1s.connect(self.smartTabGui)
-        self.app.update1s.connect(self.smartEnvironGui)
         self.app.update1s.connect(self.updateWindowsStats)
+        self.app.update1s.connect(self.setEnvironDeviceStats)
         self.app.update1s.connect(self.updateDeviceStats)
 
-    def mwSuper(self, func):
-        """
-        mwSuper is a replacement for super() to manage the mixin style of
-        implementation it's not an ideal way to do it, but mwSuper() call the
-        method of every ! parent class if they exist.
-
-        :param func:
-        :return: true for test purpose
-        """
-        for base in self.__class__.__bases__:
-            if base.__name__ == "MWidget":
-                continue
-
-            if hasattr(base, func):
-                funcAttrib = getattr(base, func)
-                funcAttrib(self)
-
-        return True
-
     def initConfig(self):
         """
         :return: True for test purpose
@@ -231,40 +253,23 @@ class MainWindow(
         Styles.colorSet = colSet
         self.ui.colorSet.setCurrentIndex(colSet)
         self.setStyleSheet(self.mw4Style)
+
         if 'mainW' not in config:
             config['mainW'] = {}
         config = config['mainW']
-        height = config.get('height', 600)
-        width = config.get('width', 800)
-        self.resize(width, height)
-        x = config.get('winPosX', 0)
-        y = config.get('winPosY', 0)
-        if x > self.screenSizeX - width:
-            x = 0
-        if y > self.screenSizeY - height:
-            y = 0
-        if x != 0 and y != 0:
-            self.move(x, y)
 
-        self.ui.mainTabWidget.setCurrentIndex(config.get('mainTabWidget', 0))
-        self.ui.settingsTabWidget.setCurrentIndex(config.get('settingsTabWidget', 0))
-        self.ui.toolsTabWidget.setCurrentIndex(config.get('toolsTabWidget', 0))
-        self.ui.satTabWidget.setCurrentIndex(config.get('satTabWidget', 0))
-        if not packageConfig.isAnalyse:
-            tabWidget = self.ui.toolsTabWidget.findChild(QWidget, 'Analyse')
-            tabIndex = self.ui.toolsTabWidget.indexOf(tabWidget)
-            self.ui.toolsTabWidget.setTabEnabled(tabIndex, False)
-
-        tabWidget = self.ui.mainTabWidget.findChild(QWidget, 'Power')
-        tabIndex = self.ui.mainTabWidget.indexOf(tabWidget)
-        self.ui.mainTabWidget.setTabEnabled(tabIndex, False)
-
-        tabWidget = self.ui.toolsTabWidget.findChild(QWidget, 'Relay')
-        tabIndex = self.ui.toolsTabWidget.indexOf(tabWidget)
-        self.ui.toolsTabWidget.setTabEnabled(tabIndex, False)
-        ui = self.ui.toolsTabWidget
-        ui.setStyleSheet(ui.styleSheet())
+        self.positionWindow(config)
         self.mwSuper('initConfig')
+        self.setTabAndIndex(self.ui.mainTabWidget, config, 'orderMain')
+        self.setTabAndIndex(self.ui.mountTabWidget, config, 'orderMount')
+        self.setTabAndIndex(self.ui.imagingTabWidget, config, 'orderImaging')
+        self.setTabAndIndex(self.ui.modelingTabWidget, config, 'orderModeling')
+        self.setTabAndIndex(self.ui.manageTabWidget, config, 'orderManage')
+        self.setTabAndIndex(self.ui.settingsTabWidget, config, 'orderSettings')
+        self.setTabAndIndex(self.ui.toolsTabWidget, config, 'orderTools')
+        self.setTabAndIndex(self.ui.satTabWidget, config, 'orderSatellite')
+        self.smartTabGui()
+        self.enableTabsMovable()
         self.changeStyleDynamic(self.ui.mountConnected, 'color', 'gray')
         self.setupIcons()
         self.show()
@@ -291,22 +296,45 @@ class MainWindow(
         config['profileName'] = self.ui.profile.text()
         if 'mainW' not in config:
             config['mainW'] = {}
+        else:
+            config['mainW'].clear()
         config = config['mainW']
+
         config['winPosX'] = self.pos().x()
         config['winPosY'] = self.pos().y()
-        config['mainTabWidget'] = self.ui.mainTabWidget.currentIndex()
-        config['settingsTabWidget'] = self.ui.settingsTabWidget.currentIndex()
-        config['toolsTabWidget'] = self.ui.toolsTabWidget.currentIndex()
-        config['satTabWidget'] = self.ui.satTabWidget.currentIndex()
+        self.getTabAndIndex(self.ui.mainTabWidget, config, 'orderMain')
+        self.getTabAndIndex(self.ui.mountTabWidget, config, 'orderMount')
+        self.getTabAndIndex(self.ui.imagingTabWidget, config, 'orderImaging')
+        self.getTabAndIndex(self.ui.modelingTabWidget, config, 'orderModeling')
+        self.getTabAndIndex(self.ui.manageTabWidget, config, 'orderManage')
+        self.getTabAndIndex(self.ui.settingsTabWidget, config, 'orderSettings')
+        self.getTabAndIndex(self.ui.toolsTabWidget, config, 'orderTools')
+        self.getTabAndIndex(self.ui.satTabWidget, config, 'orderSatellite')
         self.mwSuper('storeConfig')
         self.storeConfigExtendedWindows()
         return True
 
+    def enableTabsMovable(self):
+        """
+        :return: True for test purpose
+        """
+        isMovable = self.ui.tabsMovable.isChecked()
+        self.ui.mainTabWidget.setMovable(isMovable)
+        self.ui.mountTabWidget.setMovable(isMovable)
+        self.ui.imagingTabWidget.setMovable(isMovable)
+        self.ui.modelingTabWidget.setMovable(isMovable)
+        self.ui.manageTabWidget.setMovable(isMovable)
+        self.ui.settingsTabWidget.setMovable(isMovable)
+        self.ui.toolsTabWidget.setMovable(isMovable)
+        self.ui.satTabWidget.setMovable(isMovable)
+        self.app.tabsMovable.emit(isMovable)
+        return True
+
     def closeEvent(self, closeEvent):
         """
         :return:    nothing
         """
-        self.closing = True
+        self.gameControllerRunning = False
         self.app.timer0_1s.stop()
         self.changeStyleDynamic(self.ui.pauseModel, 'pause', False)
         self.closeExtendedWindows()
@@ -319,8 +347,8 @@ class MainWindow(
         """
         :return:    true for test purpose
         """
-        self.saveProfile()
-        self.app.saveConfig()
+        self.app.storeConfig()
+        self.saveConfig()
         self.close()
         return True
 
@@ -331,6 +359,7 @@ class MainWindow(
         # main window
         self.wIcon(self.ui.saveConfigAs, 'save')
         self.wIcon(self.ui.loadFrom, 'load')
+        self.wIcon(self.ui.addFrom, 'load')
         self.wIcon(self.ui.saveConfig, 'save')
         self.wIcon(self.ui.saveConfigQuit, 'save')
         self.wIcon(self.ui.mountOn, 'power-on')
@@ -349,40 +378,19 @@ class MainWindow(
         self.wIcon(self.ui.saveBuildPoints, 'save')
         self.wIcon(self.ui.saveBuildPointsAs, 'save')
         self.wIcon(self.ui.clearBuildP, 'trash')
-        self.wIcon(self.ui.genBuildGrid, 'run')
-        self.wIcon(self.ui.genBuildMax, 'run')
-        self.wIcon(self.ui.genBuildMed, 'run')
-        self.wIcon(self.ui.genBuildNorm, 'run')
-        self.wIcon(self.ui.genBuildMin, 'run')
-        self.wIcon(self.ui.genBuildFile, 'show')
-        self.wIcon(self.ui.genBuildAlign3, 'run')
-        self.wIcon(self.ui.genBuildAlign6, 'run')
-        self.wIcon(self.ui.genBuildAlign9, 'run')
-        self.wIcon(self.ui.genBuildGrid, 'run')
-        self.wIcon(self.ui.genBuildSpiralMax, 'run')
-        self.wIcon(self.ui.genBuildSpiralMed, 'run')
-        self.wIcon(self.ui.genBuildSpiralNorm, 'run')
-        self.wIcon(self.ui.genBuildSpiralMin, 'run')
-        self.wIcon(self.ui.genBuildDSO, 'run')
-
-        # horizon
-        self.wIcon(self.ui.loadHorizonMask, 'load')
-        self.wIcon(self.ui.saveHorizonMask, 'save')
-        self.wIcon(self.ui.saveHorizonMaskAs, 'save')
-        self.wIcon(self.ui.clearHorizonMask, 'trash')
 
         # model
         self.wIcon(self.ui.plateSolveSync, 'start')
-        pixmap = self.img2pixmap(':/pics/azimuth.png')
+        pixmap = self.img2pixmap(':/pics/azimuth.png').scaled(101, 101)
         self.ui.picAZ.setPixmap(pixmap)
-        pixmap = self.img2pixmap(':/pics/altitude.png')
+        pixmap = self.img2pixmap(':/pics/altitude.png').scaled(101, 101)
         self.ui.picALT.setPixmap(pixmap)
 
         self.wIcon(self.ui.cancelModel, 'cross-circle')
         self.wIcon(self.ui.runModel, 'start')
         self.wIcon(self.ui.pauseModel, 'pause')
         self.wIcon(self.ui.endModel, 'stop_m')
-        self.wIcon(self.ui.batchModel, 'choose')
+        self.wIcon(self.ui.dataModel, 'choose')
 
         # manage model
         self.wIcon(self.ui.runOptimize, 'start')
@@ -400,7 +408,6 @@ class MainWindow(
         self.wIcon(self.ui.refreshModel, 'reload')
 
         # minor planets
-        self.wIcon(self.ui.mpcExtendedFilter, 'cogs')
         self.wIcon(self.ui.progMinorPlanetsFull, 'run')
         self.wIcon(self.ui.progMinorPlanetsFiltered, 'run')
         self.wIcon(self.ui.progEarthRotationData, 'run')
@@ -415,8 +422,8 @@ class MainWindow(
 
         # analyse
         self.wIcon(self.ui.runFlexure, 'start')
-        self.wIcon(self.ui.runHysteresis, 'check-circle')
-        self.wIcon(self.ui.cancelAnalyse, 'cross-circle')
+        self.wIcon(self.ui.runHysteresis, 'start')
+        self.wIcon(self.ui.cancelAnalysis, 'cross-circle')
 
         # tools
         self.wIcon(self.ui.renameStart, 'start')
@@ -509,7 +516,25 @@ class MainWindow(
 
         # misc setting
         self.wIcon(self.ui.installVersion, 'world')
+        pixmap = self.svg2pixmap(':/icon/controller.svg', self.M_BLUE)
+        self.ui.controller1.setPixmap(pixmap.scaled(16, 16))
+        self.ui.controller2.setPixmap(pixmap.scaled(16, 16))
+        self.ui.controller3.setPixmap(pixmap.scaled(16, 16))
+        self.ui.controller4.setPixmap(pixmap.scaled(16, 16))
+        self.ui.controller5.setPixmap(pixmap.scaled(16, 16))
+        pixmap = self.svg2pixmap(':/icon/controllerNew.svg', self.M_BLUE)
+        self.ui.controllerOverview.setPixmap(pixmap)
+        self.ui.controller1.setEnabled(False)
+        self.ui.controller2.setEnabled(False)
+        self.ui.controller3.setEnabled(False)
+        self.ui.controller4.setEnabled(False)
+        self.ui.controller5.setEnabled(False)
 
+        # environment
+        pixmap = self.svg2pixmap(':/icon/meteoblue.svg', '#124673')
+        pixmap = pixmap.transformed(QTransform().rotate(-90))
+        pixmap = pixmap.scaled(37, 128, 1)
+        self.ui.meteoblueIcon.setPixmap(pixmap)
         return True
 
     def updateMountConnStat(self, status):
@@ -527,15 +552,12 @@ class MainWindow(
         if status and hasSim:
             self.ui.mountConnected.setEnabled(status)
             self.ui.mountConnected.setText('Mount 3D')
-
         elif status:
             self.ui.mountConnected.setText('Mount')
-
         elif not status and hasSim:
             self.ui.mountConnected.setText('Mount')
             if self.uiWindows['showSimulatorW']['classObj']:
                 self.uiWindows['showSimulatorW']['classObj'].close()
-
         return True
 
     def updateMountWeatherStat(self, setting):
@@ -548,11 +570,9 @@ class MainWindow(
         """
         if setting.weatherTemperature is None and setting.weatherPressure is None:
             self.deviceStat['directWeather'] = None
-
         else:
             if setting.weatherStatus is None:
                 self.deviceStat['directWeather'] = False
-
             else:
                 self.deviceStat['directWeather'] = True
         return True
@@ -568,47 +588,40 @@ class MainWindow(
 
         :return: true for test purpose
         """
+        isMountReady = bool(self.deviceStat.get('mount'))
+        isDomeReady = bool(self.deviceStat.get('dome'))
         isModelingReady = all(
-            self.deviceStat[x] for x in ['mount', 'camera', 'astrometry']
-        )
+            bool(self.deviceStat.get(x)) for x in ['mount', 'camera', 'plateSolve'])
         isPause = self.ui.pauseModel.property('pause')
 
         if isModelingReady and self.app.data.buildP and not isPause:
             self.ui.runModel.setEnabled(True)
+        else:
+            self.ui.runModel.setEnabled(False)
+
+        if isModelingReady:
+            self.ui.runModel.setEnabled(True)
             self.ui.plateSolveSync.setEnabled(True)
+            self.ui.dataModel.setEnabled(True)
             self.ui.runFlexure.setEnabled(True)
             self.ui.runHysteresis.setEnabled(True)
-
-        elif isModelingReady and not isPause:
-            self.ui.plateSolveSync.setEnabled(True)
-
         else:
             self.ui.runModel.setEnabled(False)
             self.ui.plateSolveSync.setEnabled(False)
+            self.ui.dataModel.setEnabled(False)
             self.ui.runFlexure.setEnabled(False)
             self.ui.runHysteresis.setEnabled(False)
 
-        if self.deviceStat.get('mount', False):
-            self.ui.batchModel.setEnabled(True)
-
-        else:
-            self.ui.batchModel.setEnabled(False)
-
-        stat = self.deviceStat.get('environOverall', None)
-
-        if stat is None:
-            self.ui.refractionGroup.setEnabled(False)
-            self.ui.setRefractionManual.setEnabled(False)
-
-        elif stat and self.deviceStat.get('mount', None):
+        if isMountReady:
             self.ui.refractionGroup.setEnabled(True)
-            self.ui.setRefractionManual.setEnabled(True)
-
+            self.ui.dsoGroup.setEnabled(True)
+            self.ui.mountCommandTable.setEnabled(True)
         else:
+            self.ui.dsoGroup.setEnabled(False)
             self.ui.refractionGroup.setEnabled(False)
-            self.ui.setRefractionManual.setEnabled(False)
+            self.ui.mountCommandTable.setEnabled(False)
 
-        if self.deviceStat.get('dome') and self.deviceStat.get('mount'):
+        if isDomeReady and isMountReady:
             self.ui.useDomeAz.setEnabled(True)
         else:
             self.ui.useDomeAz.setEnabled(False)
@@ -624,70 +637,48 @@ class MainWindow(
         smartTabs = {
             'Power': {
                 'statID': 'power',
-                'tab': self.ui.mainTabWidget,
+                'tab': self.ui.toolsTabWidget,
             },
             'Relay': {
                 'statID': 'relay',
                 'tab': self.ui.toolsTabWidget,
             },
+            'RelaySett': {
+                'statID': 'relay',
+                'tab': self.ui.settingsTabWidget,
+            },
         }
         tabChanged = False
 
         for key, tab in smartTabs.items():
-            tabWidget = smartTabs[key]['tab'].findChild(QWidget, key)
-            tabIndex = smartTabs[key]['tab'].indexOf(tabWidget)
-            tabStatus = smartTabs[key]['tab'].isTabEnabled(tabIndex)
+            tabIndex = self.getTabIndex(smartTabs[key]['tab'], key)
+            tabStatus = smartTabs[key]['tab'].isTabVisible(tabIndex)
 
             stat = bool(self.deviceStat.get(smartTabs[key]['statID']))
-            smartTabs[key]['tab'].setTabEnabled(tabIndex, stat)
-            tabChanged = tabChanged or (tabStatus != stat)
+            smartTabs[key]['tab'].setTabVisible(tabIndex, stat)
+            actChanged = tabStatus != stat
+            tabChanged = tabChanged or actChanged
+
+        tabIndex = self.getTabIndex(self.ui.imagingTabWidget, 'reference')
+        self.ui.imagingTabWidget.setTabVisible(tabIndex, packageConfig.isReference)
+        tabIndex = self.getTabIndex(self.ui.imagingTabWidget, 'AnalyseFlexure')
+        self.ui.toolsTabWidget.setTabVisible(tabIndex, packageConfig.isAnalyse)
 
         # redraw tabs only when a change occurred. this is necessary, because
         # enable and disable does not remove tabs
         if tabChanged:
             ui = self.ui.mainTabWidget
             ui.setStyleSheet(ui.styleSheet())
-            ui = self.ui.settingsTabWidget
+            ui = self.ui.toolsTabWidget
             ui.setStyleSheet(ui.styleSheet())
         return True
 
-    def smartEnvironGui(self):
-        """
-        smartEnvironGui enables and disables gui actions depending on the actual
-        state of the different environment devices. it is run every 1 second
-        synchronously, because it can't be simpler done with dynamic approach.
-        all different situations in a running environment is done locally.
-
-        :return: true for test purpose
-        """
-        environ = {
-            'directWeather': self.ui.directWeatherGroup,
-            'sensorWeather': self.ui.sensorWeatherGroup,
-            'onlineWeather': self.ui.onlineWeatherGroup,
-            'skymeter': self.ui.skymeterGroup,
-            'powerWeather': self.ui.powerGroup,
-        }
-
-        for key, group in environ.items():
-            stat = self.deviceStat.get(key, None)
-
-            if stat is None:
-                group.setFixedWidth(0)
-                group.setEnabled(False)
-            elif stat:
-                group.setMinimumSize(75, 0)
-                group.setEnabled(True)
-            else:
-                group.setMinimumSize(75, 0)
-                group.setEnabled(False)
-        return True
-
     def updateWindowsStats(self):
         """
         :return: True for test purpose
         """
-        for win in self.app.uiWindows:
-            winObj = self.app.uiWindows[win]
+        for win in self.uiWindows:
+            winObj = self.uiWindows[win]
 
             if winObj['classObj']:
                 self.changeStyleDynamic(winObj['button'], 'running', True)
@@ -695,37 +686,48 @@ class MainWindow(
                 self.changeStyleDynamic(winObj['button'], 'running', False)
         return True
 
+    def setEnvironDeviceStats(self):
+        """
+        :return:
+        """
+        refracOn = self.app.mount.setting.statusRefraction == 1
+        isManual = self.ui.refracManual.isChecked()
+        isTabEnabled = self.ui.showTabEnviron.isChecked()
+        if not refracOn or not isTabEnabled:
+            self.deviceStat['refraction'] = None
+            self.ui.refractionConnected.setText('Refraction')
+        elif isManual:
+            self.ui.refractionConnected.setText('Refrac Manu')
+            self.deviceStat['refraction'] = True
+        else:
+            self.ui.refractionConnected.setText('Refrac Auto')
+            isSource = self.deviceStat.get(self.refractionSource, False)
+            self.deviceStat['refraction'] = isSource
+        return True
+
     def updateDeviceStats(self):
         """
-        updateDeviceStats sets the colors in main window upper bar for getting
-        important overview, which functions are available.
-
-        the refraction sources etc are defined in tabEnviron, but it is optimal
-        setting the selected source right at this point as it is synchronous if
-        state is switching
-
         :return: True for test purpose
         """
-        if self.refractionSource in self.deviceStat:
-            self.deviceStat['environOverall'] = self.deviceStat[self.refractionSource]
-        else:
-            self.deviceStat['environOverall'] = None
-
         for device, ui in self.deviceStatGui.items():
-            if self.deviceStat.get(device, None) is None:
+            if self.deviceStat.get(device) is None:
                 self.changeStyleDynamic(ui, 'color', 'gray')
             elif self.deviceStat[device]:
                 self.changeStyleDynamic(ui, 'color', 'green')
             else:
                 self.changeStyleDynamic(ui, 'color', 'red')
+
+        isMount = self.deviceStat.get('mount', False)
+        self.changeStyleDynamic(self.ui.mountOn, 'running', isMount)
+        self.changeStyleDynamic(self.ui.mountOff, 'running', not isMount)
         return True
 
-    def updateAstrometryStatus(self, text):
+    def updatePlateSolveStatus(self, text):
         """
         :param text:
         :return: true for test purpose
         """
-        self.ui.astrometryText.setText(text)
+        self.ui.plateSolveText.setText(text)
         return True
 
     def updateDomeStatus(self, text):
@@ -744,28 +746,44 @@ class MainWindow(
         self.ui.cameraText.setText(text)
         return True
 
+    def updateControllerStatus(self):
+        """
+        :return: True for test purpose
+        """
+        gcStatus = self.gameControllerRunning
+        self.ui.controller1.setEnabled(gcStatus)
+        self.ui.controller2.setEnabled(gcStatus)
+        self.ui.controller3.setEnabled(gcStatus)
+        self.ui.controller4.setEnabled(gcStatus)
+        self.ui.controller5.setEnabled(gcStatus)
+        return True
+
+    def updateThreadAndOnlineStatus(self):
+        """
+        :return: True for test purpose
+        """
+        if self.ui.isOnline.isChecked():
+            mode = 'Online'
+        else:
+            mode = 'Offline'
+
+        moon = self.ui.moonPhaseIllumination.text()
+
+        f = dark_twilight_day(self.app.ephemeris, self.app.mount.obsSite.location)
+        twilight = TWILIGHTS[int(f(self.app.mount.obsSite.ts.now()))]
+
+        activeCount = self.threadPool.activeThreadCount()
+        t = f'{mode} - {twilight} - Moon: {moon}% - Threads:{activeCount:2d} / 30'
+        self.ui.statusOnline.setTitle(t)
+        return True
+
     def updateTime(self):
         """
         :return: True for test purpose
         """
         self.ui.timeComputer.setText(datetime.now().strftime('%H:%M:%S'))
-        timeJD = self.app.mount.obsSite.timeJD
-        if timeJD is not None:
-            text = timeJD.utc_strftime('%H:%M:%S')
-            self.ui.timeUTC.setText('UTC:  ' + text)
-
-        if self.ui.isOnline.isChecked():
-            mode = 'Internet Online Mode'
-        else:
-            mode = 'Offline Mode'
-
-        activeCount = self.threadPool.activeThreadCount()
-        t = f'{mode}  -  Active Threads: {activeCount:2d} / 30'
-        self.ui.statusOnline.setTitle(t)
-
         tzT = time.tzname[1] if time.daylight else time.tzname[0]
-        tzT = tzT.replace('Summer Time', 'DST')
-        t = f'Timezone: {tzT}'
+        t = f'TZ: {tzT}'
         self.ui.statusTime.setTitle(t)
         return True
 
@@ -793,6 +811,12 @@ class MainWindow(
         else:
             self.changeStyleDynamic(self.ui.stop, 'running', False)
 
+        if self.app.mount.obsSite.status == 10 and not self.satStatus:
+            self.app.playSound.emit('SatStartTracking')
+            self.satStatus = True
+        elif self.app.mount.obsSite.status != 10:
+            self.satStatus = False
+
         return True
 
     def deleteWindowResource(self, widget=None):
@@ -869,19 +893,11 @@ class MainWindow(
             self.buildWindow(window)
         return True
 
-    def closeExtendedWindows(self):
+    def waitClosedExtendedWindows(self):
         """
-        closeExtendedWindows closes all open extended windows by calling
-        close and waits until the window class is deleted.
-
-        :return: true for test purpose
+        waits until the window class is deleted
+        :return:
         """
-        for window in self.uiWindows:
-            if not self.uiWindows[window]['classObj']:
-                continue
-
-            self.uiWindows[window]['classObj'].close()
-
         waitDeleted = True
         while waitDeleted:
             for window in self.uiWindows:
@@ -892,6 +908,21 @@ class MainWindow(
             sleepAndEvents(100)
         return True
 
+    def closeExtendedWindows(self):
+        """
+        closeExtendedWindows closes all open extended windows by calling
+        close.
+
+        :return: true for test purpose
+        """
+        for window in self.uiWindows:
+            if not self.uiWindows[window]['classObj']:
+                continue
+
+            self.uiWindows[window]['classObj'].close()
+        self.waitClosedExtendedWindows()
+        return True
+
     @staticmethod
     def checkExtension(filePath, ext):
         """
@@ -903,105 +934,142 @@ class MainWindow(
             filePath += ext
         return filePath
 
-    def loadProfile(self):
+    def switchProfile(self, config):
         """
-        loadProfile interacts to get a new profile name. if a valid is received,
-        it closes all extended windows to be sure to have all setup saved,
-        than load the new profile and initializes all classes and opens the
-        necessary extended windows with their setups stored.
-        loadProfile does not save the actual configuration before loading
-        another one.
-
+        :param config:
         :return:
         """
-        folder = self.app.mwGlob['configDir']
-        loadFilePath, name, ext = self.openFile(
-            self,
-            'Open config file',
-            folder,
-            'Config files (*.cfg)',
-            enableDir=False,
-        )
-        if not name:
-            return False
-
-        # closing all windows to be base lined
         self.closeExtendedWindows()
-        self.stopDrivers()
-        suc = self.app.loadConfig(name=name)
-        if suc:
-            self.app.config['profileName'] = name
-            self.ui.profile.setText(name)
-            t = f'Profile              [{name}] loaded'
-            self.app.message.emit(t, 0)
-        else:
-            t = f'Profile              [{name}] cannot no be loaded'
-            self.app.message.emit(t, 2)
-
+        # self.stopDrivers()
+        self.app.config = config
         topo = self.app.initConfig()
         self.app.mount.obsSite.location = topo
         self.initConfig()
         self.showExtendedWindows()
         return True
 
-    def saveProfileAs(self):
+    def loadProfileGUI(self):
+        """
+        :return:
+        """
+        folder = self.app.mwGlob['configDir']
+        loadFilePath, name, ext = self.openFile(
+            self, 'Open config file', folder, 'Config files (*.cfg)',
+            enableDir=False)
+        if not name:
+            return False
+
+        config = loadProfile(configDir=self.app.mwGlob['configDir'], name=name)
+        if config:
+            self.ui.profile.setText(name)
+            self.msg.emit(1, 'System', 'Profile', f'loaded {name}')
+        else:
+            self.msg.emit(2, 'System', 'Profile error',
+                          f'{name}] cannot no be loaded')
+            return False
+
+        self.switchProfile(config)
+        return True
+
+    def addProfileGUI(self):
+        """
+        :return:
+        """
+        config = self.app.config
+        folder = self.app.mwGlob['configDir']
+        loadFilePath, name, ext = self.openFile(
+            self, 'Open add-on config file', folder, 'Config files (*.cfg)',
+            enableDir=False)
+        if not name:
+            self.ui.profileAdd.setText('-')
+            return False
+
+        self.storeConfig()
+        self.app.storeConfig()
+        configAdd = loadProfile(configDir=self.app.mwGlob['configDir'], name=name)
+        if configAdd:
+            self.ui.profileAdd.setText(name)
+            profile = self.ui.profile.text()
+            self.msg.emit(1, 'System', 'Profile', f'Base: {profile}')
+            self.msg.emit(1, 'System', 'Profile', f'Add : {name}')
+        else:
+            self.ui.profileAdd.setText('-')
+            self.msg.emit(2, 'System', 'Profile error',
+                          f'{name}] cannot no be loaded')
+            return False
+
+        config = blendProfile(config, configAdd)
+        self.switchProfile(config)
+        return True
+
+    def saveConfigAs(self):
         """
         :return:
         """
         folder = self.app.mwGlob['configDir']
         saveFilePath, name, ext = self.saveFile(
-            self,
-            'Save config file',
-            folder,
-            'Config files (*.cfg)',
-            enableDir=False,
-        )
+            self, 'Save config file', folder, 'Config files (*.cfg)',
+            enableDir=False)
         if not name:
             return False
 
         self.storeConfig()
         self.app.storeConfig()
-        suc = self.app.saveConfig(name=name)
+        suc = saveProfile(configDir=self.app.mwGlob['configDir'],
+                          name=name,
+                          config=self.app.config)
         if suc:
             self.ui.profile.setText(name)
-            t = f'Profile              [{name}] saved'
-            self.app.message.emit(t, 0)
+            self.msg.emit(1, 'System', 'Profile', f'saved {name}')
+            self.ui.profileAdd.setText('-')
         else:
-            t = f'Profile              [{name}] cannot no be saved'
-            self.app.message.emit(t, 2)
+            self.msg.emit(2, 'System', 'Profile error',
+                          f'{name}] cannot no be saved')
         return True
 
-    def saveProfile(self):
+    def saveConfig(self):
         """
-        saveProfile calls save profile in main and sends a message to the user
-        about success.
-
         :return: nothing
         """
         self.storeConfig()
         self.app.storeConfig()
-        suc = self.app.saveConfig(name=self.ui.profile.text())
+        suc = saveProfile(configDir=self.app.mwGlob['configDir'],
+                          name=self.ui.profile.text(),
+                          config=self.app.config)
         if suc:
-            self.app.message.emit('Actual profile saved', 0)
-
+            self.ui.profileAdd.setText('-')
+            self.msg.emit(1, 'System', 'Profile', 'Actual profile saved')
         else:
-            self.app.message.emit('Actual profile cannot not be saved', 2)
+            self.msg.emit(2, 'System', 'Profile',
+                          'Actual profile cannot not be saved')
         return suc
 
     def remoteCommand(self, command):
         """
         remoteCommand received signals from remote class and executes them.
-
         :param command:
         :return: True for test purpose
         """
         if command == 'shutdown':
             self.quitSave()
-            self.app.message.emit('Shutdown MW remotely', 2)
+            self.msg.emit(2, 'System', 'Remote', 'Shutdown MW4 remotely')
         elif command == 'shutdown mount':
             self.mountShutdown()
-            self.app.message.emit('Shutdown mount remotely', 2)
+            self.msg.emit(2, 'System', 'Remote', 'Shutdown MW4 remotely')
         elif command == 'boot mount':
             self.mountBoot()
-            self.app.message.emit('Boot mount remotely', 2)
+            self.msg.emit(2, 'System', 'Remote', 'Boot Mount remotely')
+        return True
+
+    def collectWindows(self):
+        """
+        :return:
+        """
+        for i, window in enumerate(self.uiWindows):
+            if self.uiWindows[window]['classObj']:
+                self.uiWindows[window]['classObj'].resize(800, 600)
+                self.uiWindows[window]['classObj'].move(i * 50 + 10, i * 50 + 10)
+                self.uiWindows[window]['classObj'].activateWindow()
+        self.move(i * 50 + 10, i * 50 + 10)
+        self.activateWindow()
         return True
