@@ -10,27 +10,23 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
 # standard libraries
+import webbrowser
 
 # external packages
-from PyQt5.QtGui import QImage, QPixmap
-import PyQt5.QtCore
-import PyQt5.QtGui
-import PyQt5.QtWidgets
-import requests
 import numpy as np
-from qimage2ndarray import rgb_view, array2qimage
+from PyQt5.QtCore import Qt
+from PyQt5.QtGui import QColor
+from PyQt5.QtWidgets import QTableWidgetItem
 
 # local import
-from base.tpool import Worker
 
 
-class Environ(object):
+class Environ:
     """
     """
 
@@ -39,50 +35,57 @@ class Environ(object):
                                   'sensorWeather': self.ui.sensorWeatherGroup,
                                   'directWeather': self.ui.directWeatherGroup,
                                   }
-
         self.refractionSource = ''
         self.filteredTemperature = None
         self.filteredPressure = None
 
-        # environment functions
         signals = self.app.sensorWeather.signals
         signals.deviceDisconnected.connect(self.clearSensorWeatherGui)
-        # skymeter functions
         signals = self.app.skymeter.signals
         signals.deviceDisconnected.connect(self.clearSkymeterGui)
-        # power weather functions
+        signals = self.app.onlineWeather.signals
+        signals.deviceDisconnected.connect(self.clearOnlineWeatherGui)
+        signals = self.app.directWeather.signals
+        signals.deviceDisconnected.connect(self.clearDirectWeatherGui)
         signals = self.app.powerWeather.signals
         signals.deviceDisconnected.connect(self.clearPowerWeatherGui)
-        # weather functions
-        self.app.onlineWeather.signals.dataReceived.connect(self.updateOnlineWeatherGui)
+        signals = self.app.seeingWeather.signals
+        signals.deviceDisconnected.connect(self.clearSeeingEntries)
+        signals = self.app.seeingWeather.signals
+        signals.deviceConnected.connect(self.prepareSeeingTable)
+
         # weather functions
         self.app.mount.signals.settingDone.connect(self.updateDirectWeatherGui)
         self.app.mount.signals.settingDone.connect(self.updateRefractionUpdateType)
         # gui connections
-        self.ui.setRefractionManual.clicked.connect(self.updateRefractionParameters)
-        self.ui.isOnline.stateChanged.connect(self.updateClearOutside)
         self.ui.onlineWeatherGroup.clicked.connect(self.selectRefractionSource)
         self.ui.sensorWeatherGroup.clicked.connect(self.selectRefractionSource)
         self.ui.directWeatherGroup.clicked.connect(self.selectRefractionSource)
-        self.ui.checkRefracNone.clicked.connect(self.setRefractionUpdateType)
-        self.ui.checkRefracCont.clicked.connect(self.setRefractionUpdateType)
-        self.ui.checkRefracNoTrack.clicked.connect(self.setRefractionUpdateType)
+        self.ui.refracManual.clicked.connect(self.setRefractionUpdateType)
+        self.ui.refracCont.clicked.connect(self.setRefractionUpdateType)
+        self.ui.refracNoTrack.clicked.connect(self.setRefractionUpdateType)
+        self.ui.unitTimeUTC.clicked.connect(self.updateSeeingEntries)
+        self.app.seeingWeather.signals.update.connect(self.prepareSeeingTable)
+        self.clickable(self.ui.meteoblueIcon).connect(self.openMeteoblue)
         # cyclic functions
+        self.app.update1s.connect(self.smartEnvironGui)
         self.app.update1s.connect(self.updateFilterRefractionParameters)
         self.app.update1s.connect(self.updateRefractionParameters)
         self.app.update1s.connect(self.updateSkymeterGui)
         self.app.update1s.connect(self.updatePowerWeatherGui)
         self.app.update1s.connect(self.updateSensorWeatherGui)
-        self.app.update30m.connect(self.updateClearOutside)
+        self.app.update1s.connect(self.updateOnlineWeatherGui)
+        self.app.update30m.connect(self.updateSeeingEntries)
+        self.app.colorChange.connect(self.updateSeeingEntries)
 
     def initConfig(self):
         """
         :return: True for test purpose
         """
         config = self.app.config['mainW']
-        self.ui.checkRefracNone.setChecked(config.get('checkRefracNone', False))
-        self.ui.checkRefracCont.setChecked(config.get('checkRefracCont', False))
-        self.ui.checkRefracNoTrack.setChecked(config.get('checkRefracNoTrack', False))
+        self.ui.refracManual.setChecked(config.get('refracManual', False))
+        self.ui.refracCont.setChecked(config.get('refracCont', False))
+        self.ui.refracNoTrack.setChecked(config.get('refracNoTrack', False))
         self.refractionSource = config.get('refractionSource', '')
         self.setRefractionSourceGui()
         return True
@@ -92,26 +95,55 @@ class Environ(object):
         :return: True for test purpose
         """
         config = self.app.config['mainW']
-        config['checkRefracNone'] = self.ui.checkRefracNone.isChecked()
-        config['checkRefracCont'] = self.ui.checkRefracCont.isChecked()
-        config['checkRefracNoTrack'] = self.ui.checkRefracNoTrack.isChecked()
+        config['refracManual'] = self.ui.refracManual.isChecked()
+        config['refracCont'] = self.ui.refracCont.isChecked()
+        config['refracNoTrack'] = self.ui.refracNoTrack.isChecked()
         config['refractionSource'] = self.refractionSource
         return True
 
-    def updateRefractionUpdateType(self, setting):
+    def smartEnvironGui(self):
+        """
+        smartEnvironGui enables and disables gui actions depending on the actual
+        state of the different environment devices. it is run every 1 second
+        synchronously, because it can't be simpler done with dynamic approach.
+        all different situations in a running environment is done locally.
+
+        :return: true for test purpose
+        """
+        environ = {
+            'directWeather': self.ui.directWeatherGroup,
+            'sensorWeather': self.ui.sensorWeatherGroup,
+            'onlineWeather': self.ui.onlineWeatherGroup,
+            'skymeter': self.ui.skymeterGroup,
+            'powerWeather': self.ui.powerGroup,
+        }
+        for key, group in environ.items():
+            stat = self.deviceStat.get(key, None)
+            if stat is None:
+                group.setFixedWidth(0)
+                group.setEnabled(False)
+            elif stat:
+                group.setMinimumSize(75, 0)
+                group.setEnabled(True)
+            else:
+                group.setMinimumSize(75, 0)
+                group.setEnabled(False)
+        return True
+
+    def updateRefractionUpdateType(self):
         """
-        :param setting:
         :return: success
         """
         if self.refractionSource != 'directWeather':
             return False
 
+        setting = self.app.mount.setting
         if setting.weatherStatus == 0:
-            self.ui.checkRefracNone.setChecked(True)
+            self.ui.refracManual.setChecked(True)
         elif setting.weatherStatus == 1:
-            self.ui.checkRefracNoTrack.setChecked(True)
+            self.ui.refracNoTrack.setChecked(True)
         elif setting.weatherStatus == 2:
-            self.ui.checkRefracCont.setChecked(True)
+            self.ui.refracCont.setChecked(True)
         else:
             return False
 
@@ -121,14 +153,16 @@ class Environ(object):
         """
         :return: success
         """
+        if not self.ui.showTabEnviron.isChecked():
+            return False
         if self.refractionSource != 'directWeather':
             suc = self.app.mount.setting.setDirectWeatherUpdateType(0)
             return suc
 
         # otherwise, we have to switch it on or off
-        if self.ui.checkRefracNone.isChecked():
+        if self.ui.refracManual.isChecked():
             suc = self.app.mount.setting.setDirectWeatherUpdateType(0)
-        elif self.ui.checkRefracNoTrack.isChecked():
+        elif self.ui.refracNoTrack.isChecked():
             suc = self.app.mount.setting.setDirectWeatherUpdateType(1)
         else:
             suc = self.app.mount.setting.setDirectWeatherUpdateType(2)
@@ -154,7 +188,7 @@ class Environ(object):
     def selectRefractionSource(self):
         """
         selectRefractionSource receives all button presses on groups and checks
-        which of the groups was clicked on. whit that information is detects the
+        which of the groups was clicked on. with that information is detects the
         index in the list of groups.
 
         :return: success
@@ -175,7 +209,6 @@ class Environ(object):
 
         self.setRefractionSourceGui()
         self.setRefractionUpdateType()
-
         return True
 
     def updateFilterRefractionParameters(self):
@@ -185,22 +218,21 @@ class Environ(object):
 
         :return:
         """
-        if self.refractionSource == 'onlineWeather':
-            if not self.app.onlineWeather.data:
-                return False
-
-            temp = self.app.onlineWeather.data['temperature']
-            press = self.app.onlineWeather.data['pressure']
-        elif self.refractionSource == 'sensorWeather':
+        if self.refractionSource == 'sensorWeather':
             key = 'WEATHER_PARAMETERS.WEATHER_TEMPERATURE'
-            temp = self.app.sensorWeather.data.get(key, None)
+            temp = self.app.sensorWeather.data.get(key)
             key = 'WEATHER_PARAMETERS.WEATHER_PRESSURE'
-            press = self.app.sensorWeather.data.get(key, None)
+            press = self.app.sensorWeather.data.get(key)
+        elif self.refractionSource == 'onlineWeather':
+            key = 'WEATHER_PARAMETERS.WEATHER_TEMPERATURE'
+            temp = self.app.onlineWeather.data.get(key)
+            key = 'WEATHER_PARAMETERS.WEATHER_PRESSURE'
+            press = self.app.onlineWeather.data.get(key)
         else:
             temp = None
             press = None
 
-        if temp is None or press is None:
+        if temp is None or press is None or press < 500:
             self.filteredTemperature = None
             self.filteredPressure = None
             return False
@@ -243,81 +275,62 @@ class Environ(object):
         """
         if self.refractionSource == 'directWeather':
             return False
-
         if not self.deviceStat['mount']:
             return False
 
         temp, press = self.movingAverageRefractionParameters()
         if temp is None or press is None:
             return False
-
-        if self.sender() != self.ui.setRefractionManual:
-            if self.ui.checkRefracNone.isChecked():
+        if self.ui.refracManual.isChecked():
+            return False
+        if self.ui.refracNoTrack.isChecked():
+            if self.app.mount.obsSite.status == 0:
                 return False
 
-            if self.ui.checkRefracNoTrack.isChecked():
-                if self.app.mount.obsSite.status == 0:
-                    return False
-
         suc = self.app.mount.setting.setRefractionParam(temperature=temp,
                                                         pressure=press)
-
+        self.log.debug(f'Setting refrac temp:[{temp}], press:[{press}]')
         if not suc:
-            self.app.message.emit('Cannot perform refraction update', 2)
+            self.msg.emit(2, 'System', 'Environment', 'No refraction update')
             return False
 
         return True
 
-    def clearSensorWeatherGui(self, deviceName):
-        """
-        :param deviceName:
-        :return: true for test purpose
-        """
-        self.ui.sensorWeatherTemp.setText('-')
-        self.ui.sensorWeatherPress.setText('-')
-        self.ui.sensorWeatherDewPoint.setText('-')
-        self.ui.sensorWeatherHumidity.setText('-')
-        self.ui.sensorWeatherCloudCover.setText('-')
-        self.ui.sensorWeatherRainVol.setText('-')
-        self.ui.sensorWeatherWindSpeed.setText('-')
-        self.ui.sensorWeatherWindDir.setText('-')
-        self.ui.sensorWeatherSQR.setText('-')
-        return True
-
     def updateSensorWeatherGui(self):
         """
         :return:    True if ok for testing
         """
         value = self.app.sensorWeather.data.get(
-            'WEATHER_PARAMETERS.WEATHER_TEMPERATURE', None)
+            'WEATHER_PARAMETERS.WEATHER_TEMPERATURE')
         self.guiSetText(self.ui.sensorWeatherTemp, '4.1f', value)
-
         value = self.app.sensorWeather.data.get(
-            'WEATHER_PARAMETERS.WEATHER_PRESSURE', None)
+            'WEATHER_PARAMETERS.WEATHER_PRESSURE')
         self.guiSetText(self.ui.sensorWeatherPress, '4.1f', value)
-
         value = self.app.sensorWeather.data.get(
-            'WEATHER_PARAMETERS.WEATHER_DEWPOINT', None)
+            'WEATHER_PARAMETERS.WEATHER_DEWPOINT')
         self.guiSetText(self.ui.sensorWeatherDewPoint, '4.1f', value)
-
         value = self.app.sensorWeather.data.get(
-            'WEATHER_PARAMETERS.WEATHER_HUMIDITY', None)
+            'WEATHER_PARAMETERS.WEATHER_HUMIDITY')
         self.guiSetText(self.ui.sensorWeatherHumidity, '3.0f', value)
+        return True
 
-        value = self.app.sensorWeather.data.get('cloudCover', None)
-        self.guiSetText(self.ui.sensorWeatherCloudCover, '3.0f', value)
+    def clearSensorWeatherGui(self, deviceName=''):
+        """
+        :param deviceName:
+        :return: true for test purpose
+        """
+        self.app.sensorWeather.data.clear()
+        self.updateSensorWeatherGui()
+        return True
 
-        value = self.app.sensorWeather.data.get('rain', None)
-        self.guiSetText(self.ui.sensorWeatherRainVol, '5.2f', value)
-
-        value = self.app.sensorWeather.data.get('windDir', None)
-        self.guiSetText(self.ui.sensorWeatherWindDir, '3.0f', value)
-
-        value = self.app.sensorWeather.data.get('windSpeed', None)
-        self.guiSetText(self.ui.sensorWeatherWindSpeed, '3.0f', value)
-
-        value = self.app.sensorWeather.data.get('SKY_QUALITY.SKY_BRIGHTNESS', None)
-        self.guiSetText(self.ui.sensorWeatherSQR, '4.2f', value)
+    def updateSkymeterGui(self):
+        """
+        :return:    True if ok for testing
+        """
+        value = self.app.skymeter.data.get('SKY_QUALITY.SKY_BRIGHTNESS')
+        self.guiSetText(self.ui.skymeterSQR, '5.2f', value)
+        value = self.app.skymeter.data.get('SKY_QUALITY.SKY_TEMPERATURE')
+        self.guiSetText(self.ui.skymeterTemp, '4.1f', value)
         return True
 
     def clearSkymeterGui(self, deviceName=''):
@@ -325,30 +338,8 @@ class Environ(object):
         :param deviceName:
         :return: true for test purpose
         """
-        self.ui.skymeterSQR.setText('-')
-        self.ui.skymeterTemp.setText('-')
-        return True
-
-    def updateSkymeterGui(self):
-        """
-        :return:    True if ok for testing
-        """
-        value = self.app.skymeter.data.get('SKY_QUALITY.SKY_BRIGHTNESS', 0)
-        self.guiSetText(self.ui.skymeterSQR, '5.2f', value)
-
-        value = self.app.skymeter.data.get('SKY_QUALITY.SKY_TEMPERATURE', 0)
-        self.guiSetText(self.ui.skymeterTemp, '4.1f', value)
-        return True
-
-    def clearPowerWeatherGui(self):
-        """
-        clearPowerWeatherGui changes the state of the Pegasus values to '-'
-
-        :return: success for test
-        """
-        self.ui.powerTemp.setText('-')
-        self.ui.powerHumidity.setText('-')
-        self.ui.powerDewPoint.setText('-')
+        self.app.skymeter.data.clear()
+        self.updateSkymeterGui()
         return True
 
     def updatePowerWeatherGui(self):
@@ -358,193 +349,68 @@ class Environ(object):
 
         :return: success for test
         """
-        value = self.app.powerWeather.data.get('WEATHER_PARAMETERS.WEATHER_TEMPERATURE', 0)
+        value = self.app.powerWeather.data.get('WEATHER_PARAMETERS.WEATHER_TEMPERATURE')
         self.guiSetText(self.ui.powerTemp, '4.1f', value)
-
-        value = self.app.powerWeather.data.get('WEATHER_PARAMETERS.WEATHER_HUMIDITY', 0)
+        value = self.app.powerWeather.data.get('WEATHER_PARAMETERS.WEATHER_HUMIDITY')
         self.guiSetText(self.ui.powerHumidity, '3.0f', value)
-
-        value = self.app.powerWeather.data.get('WEATHER_PARAMETERS.WEATHER_DEWPOINT', 0)
+        value = self.app.powerWeather.data.get('WEATHER_PARAMETERS.WEATHER_DEWPOINT')
         self.guiSetText(self.ui.powerDewPoint, '4.1f', value)
         return True
 
-    def getWebDataWorker(self, url=''):
+    def clearPowerWeatherGui(self):
         """
-        :param url:
-        :return: data
+        clearPowerWeatherGui changes the state of the Pegasus values to '-'
+
+        :return: success for test
         """
-        if not url:
-            return None
-
-        try:
-            data = requests.get(url, timeout=30)
-        except Exception as e:
-            self.log.critical(f'URL: [{url}] general exception: [{e}]')
-            return None
-
-        if data.status_code != 200:
-            self.log.warning(f'URL: [{url}] status nok')
-            return None
-
-        self.log.trace(f'URL: [{url}] status: [{data.status_code}]')
-        return data
-
-    def processClearOutsideImage(self, image=None):
-        """
-        processClearOutsideImage takes the image, split it and puts the image
-        to the Gui. for the transformation qimage2ndarray is used because of
-        the speed for the calculations. dim is a factor which reduces the
-        lightness of the overall image
-
-        :param image:
-        :return: success
-        """
-        back = self.hex2rgb(self.M_BACK)
-        m = np.mean(back)
-        dim = max((m / 256), 0.66)
-
-        image.convertToFormat(QImage.Format_RGB32)
-        imageBase = image.copy(94, 84, 585, 141)
-
-        # transformation are done in numpy, because it's much faster
-        width = imageBase.width()
-        height = imageBase.height()
-        imgArr = rgb_view(imageBase)
-        imgArr = imgArr.reshape(width * height, 3)
-
-        # transforming back
-        imgArr = imgArr.reshape(height, width, 3)
-
-        # Compressing the image as the widget content is a png
-        # removing some rows
-        m = np.isin(imgArr, [[255, 0, 0]])
-        toDelete = []
-        maxRow = 1
-        line = maxRow
-        for i in range(0, len(m[:, 1])):
-            if not line and m[i, :].all() and i > 15:
-                toDelete.append(i)
-            elif line:
-                line -= 1
-            elif not m[i][:].all():
-                line = maxRow
-        imgArr = np.delete(imgArr, toDelete, axis=0)
-
-        # re transfer to QImage from numpy array
-        imageBase = array2qimage(dim * imgArr)
-        pixmapBase = QPixmap().fromImage(imageBase)
-        return pixmapBase
-
-    def updateClearOutsideImage(self, data=None):
-        """
-        updateClearOutsideImage takes the returned data from a web fetch and
-        makes an image out of it
-
-        :param data:
-        :return: success
-        """
-        if data is None:
-            return False
-
-        image = PyQt5.QtGui.QImage()
-        if not hasattr(data, 'content'):
-            return False
-        if not isinstance(data.content, bytes):
-            return False
-
-        image.loadFromData(data.content)
-        pixmapBase = self.processClearOutsideImage(image=image)
-        self.ui.picClearOutside.setPixmap(pixmapBase)
+        self.app.powerWeather.data.clear()
+        self.updatePowerWeatherGui()
         return True
 
-    def getClearOutside(self, url=''):
+    def updateOnlineWeatherGui(self):
         """
-        getClearOutside initiates the worker thread to get the web data fetched
-
-        :param url:
-        :return:
-        """
-        worker = Worker(self.getWebDataWorker, url)
-        worker.signals.result.connect(self.updateClearOutsideImage)
-        self.threadPool.start(worker)
-
-    def updateClearOutside(self):
-        """
-        updateClearOutside downloads the actual clear outside image and displays
-        it in environment tab. it checks first if online is set, otherwise not
-        download will take place. it will be updated every 30 minutes.
-
-        confirmation for using the service :
-
-        Grant replied Aug 5, 10:01am
-        Hi Michael,
-        No problem at all embedding the forecast as shown in your image :-)
-        We appreciate the support.
-        Kindest Regards,
-        Grant
-
         :return: success
         """
-        if not self.ui.isOnline.isChecked():
-            pixmap = PyQt5.QtGui.QPixmap(':/pics/offlineMode.png')
-            self.ui.picClearOutside.setPixmap(pixmap)
-            return False
-
-        # prepare coordinates for website
-        loc = self.app.mount.obsSite.location
-        lat = loc.latitude.degrees
-        lon = loc.longitude.degrees
-
-        webSite = 'http://clearoutside.com/forecast_image_medium/'
-        url = f'{webSite}{lat:4.2f}/{lon:4.2f}/forecast.png'
-        self.getClearOutside(url=url)
+        value = self.app.onlineWeather.data.get('temperature')
+        self.guiSetText(self.ui.onlineWeatherTemp, '4.1f', value)
+        value = self.app.onlineWeather.data.get('pressure')
+        self.guiSetText(self.ui.onlineWeatherPress, '5.1f', value)
+        value = self.app.onlineWeather.data.get('humidity')
+        self.guiSetText(self.ui.onlineWeatherHumidity, '3.0f', value)
+        value = self.app.onlineWeather.data.get('dewPoint')
+        self.guiSetText(self.ui.onlineWeatherDewPoint, '4.1f', value)
+        value = self.app.onlineWeather.data.get('cloudCover')
+        self.guiSetText(self.ui.onlineWeatherCloudCover, '3.0f', value)
+        value = self.app.onlineWeather.data.get('rain')
+        self.guiSetText(self.ui.onlineWeatherRainVol, '5.2f', value)
         return True
 
     def clearOnlineWeatherGui(self):
         """
+        updateOnlineWeatherGui takes the returned data from the dict to the Gui
+
         :return: true for test purpose
         """
-        self.ui.onlineWeatherTemp.setText('-')
-        self.ui.onlineWeatherPress.setText('-')
-        self.ui.onlineWeatherHumidity.setText('-')
-        self.ui.onlineWeatherDewPoint.setText('-')
-        self.ui.onlineWeatherCloudCover.setText('-')
-        self.ui.onlineWeatherWindSpeed.setText('-')
-        self.ui.onlineWeatherWindDir.setText('-')
-        self.ui.onlineWeatherRainVol.setText('-')
+        self.app.onlineWeather.data.clear()
+        self.updateOnlineWeatherGui()
         return True
 
-    def updateOnlineWeatherGui(self, data=None):
+    def updateDirectWeatherGui(self):
         """
         :return: success
         """
-        if not data:
-            self.clearOnlineWeatherGui()
-            return False
-
-        value = self.app.onlineWeather.data.get('temperature', None)
-        self.guiSetText(self.ui.onlineWeatherTemp, '4.1f', value)
-
-        value = self.app.onlineWeather.data.get('pressure', None)
-        self.guiSetText(self.ui.onlineWeatherPress, '5.1f', value)
-
-        value = self.app.onlineWeather.data.get('humidity', None)
-        self.guiSetText(self.ui.onlineWeatherHumidity, '3.0f', value)
-
-        value = self.app.onlineWeather.data.get('dewPoint', None)
-        self.guiSetText(self.ui.onlineWeatherDewPoint, '4.1f', value)
-
-        value = self.app.onlineWeather.data.get('cloudCover', None)
-        self.guiSetText(self.ui.onlineWeatherCloudCover, '3.0f', value)
-
-        value = self.app.onlineWeather.data.get('windSpeed', None)
-        self.guiSetText(self.ui.onlineWeatherWindSpeed, '3.0f', value)
-
-        value = self.app.onlineWeather.data.get('windDir', None)
-        self.guiSetText(self.ui.onlineWeatherWindDir, '3.0f', value)
-
-        value = self.app.onlineWeather.data.get('rain', None)
-        self.guiSetText(self.ui.onlineWeatherRainVol, '5.2f', value)
+        value = self.app.directWeather.data.get(
+            'WEATHER_PARAMETERS.WEATHER_TEMPERATURE')
+        self.guiSetText(self.ui.directWeatherTemp, '4.1f', value)
+        value = self.app.directWeather.data.get(
+            'WEATHER_PARAMETERS.WEATHER_PRESSURE')
+        self.guiSetText(self.ui.directWeatherPress, '4.1f', value)
+        value = self.app.directWeather.data.get(
+            'WEATHER_PARAMETERS.WEATHER_DEWPOINT')
+        self.guiSetText(self.ui.directWeatherDewPoint, '4.1f', value)
+        value = self.app.directWeather.data.get(
+            'WEATHER_PARAMETERS.WEATHER_HUMIDITY')
+        self.guiSetText(self.ui.directWeatherHumidity, '3.0f', value)
         return True
 
     def clearDirectWeatherGui(self):
@@ -553,33 +419,131 @@ class Environ(object):
 
         :return: true for test purpose
         """
-        self.ui.directWeatherTemp.setText('-')
-        self.ui.directWeatherPress.setText('-')
-        self.ui.directWeatherHumidity.setText('-')
-        self.ui.directWeatherDewPoint.setText('-')
+        self.app.directWeather.data.clear()
+        self.updateDirectWeatherGui()
         return True
 
-    def updateDirectWeatherGui(self, setting=None):
+    def addSkyfieldTimeObject(self, data):
         """
-        :param setting:
-        :return: success
+        :param data:
+        :return:
         """
-        if not self.deviceStat['directWeather']:
-            self.clearDirectWeatherGui()
-            return False
+        ts = self.app.mount.obsSite.ts
+        data['time'] = []
 
-        if setting is None:
+        for date, hour in zip(data['date'], data['hour']):
+            y, m, d = date.split('-')
+            data['time'].append(ts.utc(int(y), int(m), int(d), hour, 0, 0))
+        return True
+
+    def updateSeeingEntries(self):
+        """
+        :return:
+        """
+        if 'hourly' not in self.app.seeingWeather.data:
             return False
+
+        self.ui.seeingGroup.setTitle('Seeing data ' + self.timeZoneString())
+        ts = self.app.mount.obsSite.ts
+        fields = ['time', 'time', 'high_clouds', 'mid_clouds', 'low_clouds',
+                  'seeing_arcsec', 'seeing1', 'seeing2', 'temperature',
+                  'relative_humidity', 'badlayer_top', 'badlayer_bottom',
+                  'badlayer_gradient', 'jetstream']
+        colorMain = self.cs['M_BLUE'][0]
+        colorBlack = self.cs['M_BLACK'][0]
+        colorWhite = self.cs['M_WHITE'][0]
+        seeTab = self.ui.tableSeeing
+        data = self.app.seeingWeather.data['hourly']
+        self.addSkyfieldTimeObject(data)
+
+        for i in range(0, 96):
+            isActual = abs(data['time'][i] - ts.now()) < 1 / 48
+
+            for j, field in enumerate(fields):
+                t = f'{data[field][i]}'
+                item = QTableWidgetItem()
+                item.setTextAlignment(Qt.AlignHCenter)
+                item.setForeground(QColor(self.M_BLUE))
+
+                if j == 0:
+                    t = self.convertTime(data[field][i], '%d%b')
+                elif j == 1:
+                    t = self.convertTime(data[field][i], '%H:00')
+                elif j in [2, 3, 4]:
+                    color = self.calcHexColor(colorMain, data[field][i] / 100)
+                    item.setBackground(QColor(color))
+                    item.setForeground(QColor(colorWhite))
+                elif j in [6]:
+                    color = self.calcHexColor(data['seeing1_color'][i], 0.8)
+                    item.setBackground(QColor(color))
+                    item.setForeground(QColor(colorBlack))
+                elif j in [7]:
+                    color = self.calcHexColor(data['seeing2_color'][i], 0.8)
+                    item.setBackground(QColor(color))
+                    item.setForeground(QColor(colorBlack))
+                elif j in [10, 11]:
+                    val = float('0' + data[field][i]) / 1000
+                    t = f'{val:1.1f}'
+
+                if isActual:
+                    item.setForeground(QColor(self.M_PINK))
+                    val = data['seeing_arcsec'][i]
+                    self.ui.limitForecast.setText(f'{val}')
+                    val = self.app.seeingWeather.data['meta']['last_model_update']
+                    self.ui.limitForecastDate.setText(f'{val}')
+                    columnCenter = i
+                else:
+                    columnCenter = 1
+
+                item.setText(t)
+                seeTab.setItem(j, i, item)
+
+        seeTab.selectColumn(columnCenter + 10)
+        return True
 
-        value = setting.weatherTemperature
-        self.guiSetText(self.ui.directWeatherTemp, '4.1f', value)
+    def clearSeeingEntries(self):
+        """
+        :return:
+        """
+        self.ui.tableSeeing.clear()
+        return True
 
-        value = setting.weatherPressure
-        self.guiSetText(self.ui.directWeatherPress, '5.1f', value)
+    def prepareSeeingTable(self):
+        """
+        :return:
+        """
+        vl = ['Date [dd mon]',
+              'Hour [hh:mm]',
+              'Low clouds  [%]',
+              'Mid clouds  [%]',
+              'High clouds [%]',
+              'Seeing [arcsec]',
+              'Seeing index 1',
+              'Seeing index 2',
+              'Ground Temp [°C]',
+              'Humidity [%]',
+              'Bad Layers Top [km]',
+              'Bad Layers Bot [km]',
+              'Bad Layers [K/100m]',
+              'Jet stream [m/s]',
+              ]
 
-        value = setting.weatherHumidity
-        self.guiSetText(self.ui.directWeatherHumidity, '3.0f', value)
+        seeTab = self.ui.tableSeeing
+        seeTab.setRowCount(14)
+        seeTab.setColumnCount(96)
+        seeTab.setVerticalHeaderLabels(vl)
+        seeTab.verticalHeader().setDefaultSectionSize(18)
+        self.updateSeeingEntries()
+        seeTab.resizeColumnsToContents()
+        return True
 
-        value = setting.weatherDewPoint
-        self.guiSetText(self.ui.directWeatherDewPoint, '4.1f', value)
+    def openMeteoblue(self):
+        """
+        :return:
+        """
+        url = 'https://www.meteoblue.com/de/wetter/outdoorsports/seeing'
+        if not webbrowser.open(url, new=0):
+            self.msg.emit(2, 'System', 'Environment', 'Browser failed')
+        else:
+            self.msg.emit(0, 'System', 'Environment', 'Meteoblue opened')
         return True
