@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -21,7 +21,7 @@ import os
 import PyQt5
 from PyQt5.QtCore import Qt, QRect, QPoint, pyqtSignal
 from PyQt5.QtWidgets import QApplication, QAbstractItemView
-from PyQt5.QtWidgets import QTableWidgetItem, QHeaderView
+from PyQt5.QtWidgets import QTableWidgetItem
 import numpy as np
 from skyfield import almanac
 
@@ -120,6 +120,7 @@ class SatSearch(object):
 
         self.app.update1s.connect(self.satCalcDynamicTable)
         self.app.update10m.connect(self.updateSatTable)
+        self.ui.unitTimeUTC.clicked.connect(self.satCalcTable)
 
     def initConfig(self):
         """
@@ -346,7 +347,7 @@ class SatSearch(object):
 
         if isUp is not None:
             if isUp[0]:
-                t = f'{isUp[1][0].tt_strftime("%H:%M")}'
+                t = self.convertTime(isUp[1][0], '%H:%M')
             else:
                 t = ''
 
@@ -375,7 +376,7 @@ class SatSearch(object):
         """
         :return:
         """
-        if not self.satTableDynamicValid or self.closing:
+        if not self.satTableDynamicValid:
             return False
         if self.ui.satTabWidget.currentIndex() != 0:
             return False
@@ -500,7 +501,7 @@ class SatSearch(object):
 
         for row in range(numSats):
             QApplication.processEvents()
-            if not self.satTableBaseValid or self.closing:
+            if not self.satTableBaseValid:
                 break
             name = satTab.model().index(row, 1).data()
             sat = self.satellites[name]
@@ -541,9 +542,11 @@ class SatSearch(object):
         """
         :return:
         """
-        if not self.satTableBaseValid or self.closing:
+        if not self.satTableBaseValid:
             return False
 
+        title = 'Setup ' + self.timeZoneString()
+        self.ui.satSetupGroup.setTitle(title)
         self.satTableDynamicValid = False
         self.ui.satIsUp.setEnabled(False)
         self.ui.satIsSunlit.setEnabled(False)
@@ -583,10 +586,8 @@ class SatSearch(object):
         satTab.setColumnWidth(6, 50)
         satTab.setColumnWidth(7, 45)
         satTab.setColumnWidth(8, 0)
-        satTab.horizontalHeader().setSectionResizeMode(QHeaderView.Fixed)
-        satTab.verticalHeader().setSectionResizeMode(QHeaderView.Fixed)
-        satTab.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
         satTab.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
+        satTab.verticalHeader().setDefaultSectionSize(16)
         return True
 
     def setupSatelliteNameList(self):
@@ -601,8 +602,8 @@ class SatSearch(object):
 
         for name in self.satellites:
             number = self.satellites[name].model.satnum
-            satTab.insertRow(satTab.rowCount())
-            row = satTab.rowCount() - 1
+            row = satTab.rowCount()
+            satTab.insertRow(row)
             entry = QTableWidgetItem(f'{number:5d}')
             entry.setTextAlignment(Qt.AlignRight | Qt.AlignVCenter)
             satTab.setItem(row, 0, entry)
@@ -624,7 +625,7 @@ class SatSearch(object):
         loader = self.app.mount.obsSite.loader
         fileName = os.path.basename(source)
         dirPath = self.app.mwGlob['dataDir']
-        filePath = f'{dirPath}/{fileName}'
+        filePath = os.path.normpath(f'{dirPath}/{fileName}')
         if not isOnline:
             source = filePath
         satellites = loader.tle_file(source, reload=isOnline)
@@ -671,15 +672,17 @@ class SatSearch(object):
         """
         suc = self.databaseProcessing.writeSatelliteTLE(satellites, self.installPath)
         if not suc:
-            self.app.message.emit('Data could not be exported - stopping', 2)
+            self.msg.emit(2, 'TLE', 'Data error',
+                          'Data could not be exported - stopping')
             return False
 
-        self.app.message.emit('Uploading TLE data to mount', 0)
+        self.msg.emit(0, 'TLE', 'Program', 'Uploading to mount')
         suc = self.app.automation.uploadTLEData()
         if not suc:
-            self.app.message.emit('Uploading error, files available', 2)
+            self.msg.emit(2, 'TLE', 'Program error',
+                          'Uploading error but files available')
         else:
-            self.app.message.emit('Programming success', 1)
+            self.msg.emit(1, 'TLE', 'Program', 'Successful uploaded')
         return suc
 
     def satelliteFilter(self, satellitesRaw):
@@ -718,8 +721,8 @@ class SatSearch(object):
         if not suc:
             return False
 
-        self.app.message.emit(f'Program database:    [{source}]', 1)
-        self.app.message.emit('Exporting TLE data', 0)
+        self.msg.emit(1, 'TLE', 'Program', f'{source}')
+        self.msg.emit(1, '', '', 'Exporting TLE data')
         return True
 
     def progSatellitesFiltered(self):
