@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -63,12 +62,7 @@ class SettDevice:
         start new driver
     """
 
-    def __init__(self, app=None, ui=None, clickable=None):
-        if app:
-            self.app = app
-            self.ui = ui
-            self.clickable = clickable
-
+    def __init__(self):
         self.popupUi = None
         self.drivers = {
             'dome': {
@@ -117,7 +111,13 @@ class SettDevice:
                 'uiDropDown': self.ui.onlineWeatherDevice,
                 'uiSetup': self.ui.onlineWeatherSetup,
                 'class': self.app.onlineWeather,
-                'deviceType': None,
+                'deviceType': 'observingconditions',
+            },
+            'seeingWeather': {
+                'uiDropDown': self.ui.seeingWeatherDevice,
+                'uiSetup': self.ui.seeingWeatherSetup,
+                'class': self.app.seeingWeather,
+                'deviceType': 'observingconditions',
             },
             'skymeter': {
                 'uiDropDown': self.ui.skymeterDevice,
@@ -149,11 +149,11 @@ class SettDevice:
                 'class': self.app.relay,
                 'deviceType': None,
             },
-            'astrometry': {
-                'uiDropDown': self.ui.astrometryDevice,
-                'uiSetup': self.ui.astrometrySetup,
-                'class': self.app.astrometry,
-                'deviceType': 'astrometry',
+            'plateSolve': {
+                'uiDropDown': self.ui.plateSolveDevice,
+                'uiSetup': self.ui.plateSolveSetup,
+                'class': self.app.plateSolve,
+                'deviceType': 'plateSolve',
             },
             'remote': {
                 'uiDropDown': self.ui.remoteDevice,
@@ -219,20 +219,25 @@ class SettDevice:
         :return: True for test purpose
         """
         config = self.app.config['mainW']
-        if 'driversData' not in config:
-            config['driversData'] = {}
+        configD = self.app.config
+        if 'driversData' not in configD:
+            configD['driversData'] = {}
 
+        # adding default for missing drivers
         for driver in self.drivers:
-            if driver in config['driversData']:
-                self.checkStructureDriversData(driver, config)
-            else:
-                self.setDefaultData(driver, config)
+            if driver not in configD['driversData']:
+                self.setDefaultData(driver, configD)
 
-        self.driversData.update(config.get('driversData', {}))
-        self.ui.checkASCOMAutoConnect.setChecked(config.get('checkASCOMAutoConnect', False))
+        # remove unknown drivers from data
+        for driver in list(configD['driversData'].keys()):
+            if driver not in self.drivers:
+                del configD['driversData'][driver]
+
+        self.driversData.clear()
+        self.driversData.update(configD.get('driversData', {}))
+        self.ui.autoConnectASCOM.setChecked(config.get('autoConnectASCOM', False))
         self.setupDeviceGui()
         self.startDrivers()
-
         return True
 
     def storeConfig(self):
@@ -240,8 +245,9 @@ class SettDevice:
         :return: True for test purpose
         """
         config = self.app.config['mainW']
-        config['driversData'] = self.driversData
-        config['checkASCOMAutoConnect'] = self.ui.checkASCOMAutoConnect.isChecked()
+        configD = self.app.config
+        configD['driversData'] = self.driversData
+        config['autoConnectASCOM'] = self.ui.autoConnectASCOM.isChecked()
         return True
 
     def setupDeviceGui(self):
@@ -272,7 +278,6 @@ class SettDevice:
             framework = self.driversData[driver]['framework']
             index = self.findIndexValue(self.drivers[driver]['uiDropDown'], framework)
             self.drivers[driver]['uiDropDown'].setCurrentIndex(index)
-
         return True
 
     def processPopupResults(self):
@@ -333,17 +338,13 @@ class SettDevice:
                 continue
             if framework not in self.driversData[driverLoop]['frameworks']:
                 continue
-
             for param in self.driversData[driverLoop]['frameworks'][framework]:
+                # no local information should be copied
                 if param in ['deviceList', 'deviceName']:
-                    # should be not copied
                     continue
 
                 source = self.driversData[driver]['frameworks'][framework][param]
                 self.driversData[driverLoop]['frameworks'][framework][param] = source
-
-            if driverClass.framework == framework:
-                self.startDriver(driver=driver)
         return True
 
     def callPopup(self, driver):
@@ -399,10 +400,12 @@ class SettDevice:
             driverClass.stopCommunication()
             driverClass.data.clear()
             driverClass.run[framework].deviceName = ''
-            self.app.message.emit(f'Disabled device:     [{driver}]', 0)
+            self.msg.emit(0, 'Driver',
+                          f'{framework.upper()} disabled',
+                          f'{driver}')
 
-        self.drivers[driver]['uiDropDown'].setStyleSheet(f'background-color: '
-                                                         f'{self.M_GREY1};')
+        self.changeStyleDynamic(self.drivers[driver]['uiDropDown'],
+                                'active', False)
         self.deviceStat[driver] = None
 
         return True
@@ -436,14 +439,14 @@ class SettDevice:
 
     def startDriver(self, driver=None, autoStart=True):
         """
-        startDriver checks if a framework has been set and starts the driver with its
-        startCommunication method. Normally the driver would report it's connection,
-        but for internal driver this has to be done separately.
+        startDriver checks if a framework has been set and starts the driver with
+        its startCommunication method. Normally the driver would report it's
+        connection, but for internal driver this has to be done separately.
 
-        as the configuration is stored in the config, start also stores the selected
-        framework in the framework attribute of the driver's class. this is needed as
-        when stopping the driver the config dict already has the new framework set
-        and we have to remember it.
+        as the configuration is stored in the config, start also stores the
+        selected framework in the framework attribute of the driver's class. this
+        is needed as when stopping the driver the config dict already has the new
+        framework set, and we have to remember it.
 
         :param driver:
         :param autoStart:
@@ -457,18 +460,26 @@ class SettDevice:
         if not framework:
             return False
 
-        loadConfig = data.get('loadConfig', False)
         driverClass = self.drivers[driver]['class']
+
+        loadConfig = data['frameworks'][framework].get('loadConfig', False)
+        updateRate = data['frameworks'][framework].get('updateRate', 1000)
+        driverClass.updateRate = updateRate
+        driverClass.loadConfig = loadConfig
+
         driverClass.framework = framework
         isInternal = framework == 'internal'
         if isInternal:
-            self.drivers[driver]['uiDropDown'].setStyleSheet(f'background-color: {self.M_GREEN};')
+            self.changeStyleDynamic(self.drivers[driver]['uiDropDown'],
+                                    'active', True)
 
         self.configDriver(driver=driver)
         if autoStart:
-            driverClass.startCommunication(loadConfig=loadConfig)
+            driverClass.startCommunication()
 
-        self.app.message.emit(f'Enabled device:      [{driver}]', 0)
+        self.msg.emit(0, 'Driver',
+                      f'{framework.upper()} enabled',
+                      f'{driver}')
         return True
 
     def startDrivers(self):
@@ -478,7 +489,7 @@ class SettDevice:
 
         :return: true for test purpose
         """
-        isAscomAutoConnect = self.ui.checkASCOMAutoConnect.isChecked()
+        isAscomAutoConnect = self.ui.autoConnectASCOM.isChecked()
         for driver in self.drivers:
             if driver not in self.driversData:
                 continue
@@ -588,9 +599,7 @@ class SettDevice:
             if not self.scanValid(driver=driver, deviceName=deviceName):
                 continue
 
-            self.drivers[driver]['uiDropDown'].setStyleSheet(f'background-color: '
-                                                             f'{self.M_GREY1};')
-            self.app.message.emit(f'Disconnected server: [{driver}] ', 0)
+            self.msg.emit(0, 'Driver', 'Server disconnected', f'{driver}')
         return True
 
     def deviceConnected(self, deviceName):
@@ -605,9 +614,15 @@ class SettDevice:
             if not self.scanValid(driver=driver, deviceName=deviceName):
                 continue
 
-            self.drivers[driver]['uiDropDown'].setStyleSheet(f'background-color: {self.M_GREEN};')
+            self.changeStyleDynamic(self.drivers[driver]['uiDropDown'],
+                                    'active', True)
             self.deviceStat[driver] = True
-            self.app.message.emit(f'Device connected:    [{driver}]', 0)
+            self.msg.emit(0, 'Driver', 'Device connected', f'{driver}')
+
+            data = self.driversData[driver]
+            framework = data['framework']
+            if data['frameworks'][framework].get('loadConfig', False):
+                self.msg.emit(0, 'Driver', 'Config loaded', f'{driver}')
         return True
 
     def deviceDisconnected(self, deviceName):
@@ -619,8 +634,8 @@ class SettDevice:
             if not self.scanValid(driver=driver, deviceName=deviceName):
                 continue
 
-            self.drivers[driver]['uiDropDown'].setStyleSheet(f'background-color: '
-                                                             f'{self.M_GREY1};')
+            self.changeStyleDynamic(self.drivers[driver]['uiDropDown'],
+                                    'active', False)
             self.deviceStat[driver] = False
-            self.app.message.emit(f'Disconnected device: [{driver}]', 0)
+            self.msg.emit(0, 'Driver', 'Device disconnected', f'{driver}')
         return True
