@@ -10,17 +10,18 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
 # standard libraries
+import ipaddress
 
 # external packages
 import wakeonlan
 
 # local import
+from mountcontrol.mount import checkFormatMAC
 
 
 class SettMount(object):
@@ -29,7 +30,9 @@ class SettMount(object):
 
     def __init__(self):
         self.ui.mountOn.clicked.connect(self.mountBoot)
+        self.app.mountOn.connect(self.mountBoot)
         self.ui.mountOff.clicked.connect(self.mountShutdown)
+        self.app.mountOff.connect(self.mountShutdown)
         self.ui.mountHost.editingFinished.connect(self.mountHost)
         self.ui.port3492.clicked.connect(self.mountHost)
         self.ui.port3490.clicked.connect(self.mountHost)
@@ -38,6 +41,10 @@ class SettMount(object):
         self.app.mount.signals.settingDone.connect(self.setMountMAC)
         self.app.mount.signals.firmwareDone.connect(self.updateFwGui)
         self.ui.settleTimeMount.valueChanged.connect(self.setMountSettlingTime)
+        self.app.update30s.connect(self.syncClock)
+        self.ui.clockSync.stateChanged.connect(self.toggleClockSync)
+        self.ui.copyFromTelescopeDriver.clicked.connect(self.updateTelescopeParametersToGui)
+        self.app.update3s.connect(self.updateTelescopeParametersToGuiCyclic)
 
     def initConfig(self):
         """
@@ -54,6 +61,16 @@ class SettMount(object):
         self.ui.mountWolPort.setText(config.get('mountWolPort', '9'))
         self.ui.rackCompMAC.setText(config.get('rackCompMAC', ''))
         self.ui.settleTimeMount.setValue(config.get('settleTimeMount', 0))
+        self.ui.automaticTelescope.setChecked(config.get('automaticTelescope', False))
+        self.ui.automaticWOL.setChecked(config.get('automaticWOL', False))
+        self.ui.syncTimeNone.setChecked(config.get('syncTimeNone', True))
+        self.ui.syncTimeCont.setChecked(config.get('syncTimeCont', False))
+        self.ui.syncTimeNotTrack.setChecked(config.get('syncTimeNotTrack', False))
+        self.ui.clockSync.setChecked(config.get('clockSync', False))
+        self.toggleClockSync()
+
+        if self.ui.automaticWOL.isChecked():
+            self.mountBoot()
         return True
 
     def storeConfig(self):
@@ -68,6 +85,12 @@ class SettMount(object):
         config['rackCompMAC'] = self.ui.rackCompMAC.text()
         config['settleTimeMount'] = self.ui.settleTimeMount.value()
         config['port3492'] = self.ui.port3492.isChecked()
+        config['automaticTelescope'] = self.ui.automaticTelescope.isChecked()
+        config['automaticWOL'] = self.ui.automaticWOL.isChecked()
+        config['syncTimeNone'] = self.ui.syncTimeNone.isChecked()
+        config['syncTimeCont'] = self.ui.syncTimeCont.isChecked()
+        config['syncTimeNotTrack'] = self.ui.syncTimeNotTrack.isChecked()
+        config['clockSync'] = self.ui.clockSync.isChecked()
         return True
 
     def mountBoot(self):
@@ -77,12 +100,12 @@ class SettMount(object):
         bAddress = self.ui.mountWolAddress.text().strip()
         bPort = self.ui.mountWolPort.text().strip()
         bPort = (int(bPort) if bPort else 0)
-        suc = self.app.mount.bootMount(bAddress=bAddress,
-                                       bPort=bPort)
+        suc = self.app.mount.bootMount(bAddress=bAddress, bPort=bPort)
         if suc:
-            self.app.message.emit('Sent boot command to mount', 0)
+            self.msg.emit(0, 'Mount', 'Command',
+                          'Sent boot command to mount')
         else:
-            self.app.message.emit('Mount cannot be booted', 2)
+            self.msg.emit(2, 'Mount', 'Command', 'Mount cannot be booted')
         return suc
 
     def mountShutdown(self):
@@ -91,56 +114,25 @@ class SettMount(object):
         """
         suc = self.app.mount.shutdown()
         if suc:
-            self.app.message.emit('Shutting mount down', 0)
+            self.msg.emit(0, 'Mount', 'Command', 'Shutting mount down')
         else:
-            self.app.message.emit('Mount cannot be shutdown', 2)
+            self.msg.emit(2, 'Mount', 'Command', 'Mount cannot be shutdown')
         return suc
 
-    def checkFormatMAC(self, value):
-        """
-        :param      value: string with mac address
-        :return:    checked string in upper cases
-        """
-        if not value:
-            self.log.info('wrong MAC value: {0}'.format(value))
-            return None
-        if not isinstance(value, str):
-            self.log.info('wrong MAC value: {0}'.format(value))
-            return None
-
-        value = value.upper()
-        value = value.replace('.', ':')
-        value = value.split(':')
-        if len(value) != 6:
-            self.log.info('wrong MAC value: {0}'.format(value))
-            return None
-
-        for chunk in value:
-            if len(chunk) != 2:
-                self.log.info('wrong MAC value: {0}'.format(value))
-                return None
-
-            for char in chunk:
-                if char not in ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9',
-                                'A', 'B', 'C', 'D', 'E', 'F']:
-                    self.log.info('wrong MAC value: {0}'.format(value))
-                    return None
-
-        value = '{0:2s}:{1:2s}:{2:2s}:{3:2s}:{4:2s}:{5:2s}'.format(*value)
-        return value
-
     def bootRackComp(self):
         """
         :return:
         """
         MAC = self.ui.rackCompMAC.text()
-        MAC = self.checkFormatMAC(MAC)
+        MAC = checkFormatMAC(MAC)
         if MAC is not None:
             wakeonlan.send_magic_packet(MAC)
-            self.app.message.emit('Sent boot command to rack computer', 0)
+            self.msg.emit(0, 'Rack', 'Command',
+                          'Sent boot command to rack computer')
             return True
         else:
-            self.app.message.emit('Rack computer cannot be booted', 2)
+            self.msg.emit(2, 'Rack', 'Command',
+                          'Rack computer cannot be booted')
             return False
 
     def mountHost(self):
@@ -152,7 +144,16 @@ class SettMount(object):
         else:
             port = 3490
 
-        self.app.mount.host = (self.ui.mountHost.text(), port)
+        host = self.ui.mountHost.text()
+        if not host:
+            return False
+        try:
+            ipaddress.ip_address(host)
+        except Exception as e:
+            self.msg.emit(2, 'Mount', 'Setting error', f'{e}')
+            return False
+
+        self.app.mount.host = (host, port)
         self.app.hostChanged.emit()
         return True
 
@@ -196,3 +197,85 @@ class SettMount(object):
         self.guiSetText(self.ui.fwtime, 's', fw.time)
         self.guiSetText(self.ui.hardware, 's', fw.hardware)
         return True
+
+    def toggleClockSync(self):
+        """
+        :return:
+        """
+        enableSync = self.ui.clockSync.isChecked()
+        self.ui.syncTimeNone.setEnabled(enableSync)
+        self.ui.syncTimeCont.setEnabled(enableSync)
+        self.ui.syncTimeNotTrack.setEnabled(enableSync)
+        self.ui.clockOffset.setEnabled(enableSync)
+        self.ui.clockOffsetMS.setEnabled(enableSync)
+        if enableSync:
+            self.app.mount.startClockTimer()
+        else:
+            self.app.mount.stopClockTimer()
+        return True
+
+    def syncClock(self):
+        """
+        :return:
+        """
+        noSync = self.ui.syncTimeNone.isChecked()
+        if noSync:
+            return False
+        if not self.deviceStat['mount']:
+            return False
+
+        doSyncNotTrack = self.ui.syncTimeNotTrack.isChecked()
+        mountTracks = self.app.mount.obsSite.status in [0, 10]
+        if doSyncNotTrack and mountTracks:
+            return False
+
+        delta = self.app.mount.obsSite.timeDiff * 1000
+        if abs(delta) < 10:
+            return False
+
+        if delta > 999:
+            delta = 999
+        if delta < -999:
+            delta = -999
+
+        delta = int(delta)
+        suc = self.app.mount.obsSite.adjustClock(delta)
+        if not suc:
+            self.msg.emit(2, 'System', 'Clock',
+                          'Cannot adjust mount clock')
+            return False
+
+        self.msg.emit(0, 'System', 'Clock',
+                      f'Correction: [{-delta} ms]')
+        return True
+
+    def updateTelescopeParametersToGui(self):
+        """
+        updateTelescopeParametersToGui takes the information gathered from the
+        driver and programs them into gui for later use.
+
+        :return: true for test purpose
+        """
+
+        value = self.app.telescope.data.get(
+            'TELESCOPE_INFO.TELESCOPE_FOCAL_LENGTH', 0)
+        if value is not None:
+            value = float(value)
+            self.ui.focalLength.setValue(value)
+
+        value = self.app.telescope.data.get('TELESCOPE_INFO.TELESCOPE_APERTURE',
+                                            0)
+        if value is not None:
+            value = float(value)
+            self.ui.aperture.setValue(value)
+
+        return True
+
+    def updateTelescopeParametersToGuiCyclic(self):
+        """
+        :return:
+        """
+        if not self.ui.automaticTelescope.isChecked():
+            return False
+        self.updateTelescopeParametersToGui()
+        return True
