@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -40,17 +39,23 @@ class Styles:
             'M_GREY1': ['#282828', '#201010', '#C0C0C0', ],
             'M_BACK': ['#181818', '#181818', '#E0E0E0', ],
             'M_BLACK': ['#000000', '#000000', '#FFFFFF', ],
-            'M_RED': ['#C03030', '#C03030', '#900000', ],
-            'M_RED1': ['#802020', '#802020', '#900000', ],
-            'M_YELLOW': ['#C0C000', '#808000', '#909000', ],
-            'M_YELLOW1': ['#808000', '#606000', '#909000', ],
-            'M_GREEN': ['#008000', '#006000', '#009000', ],
-            'M_GREEN1': ['#006000', '#004000', '#009000', ],
+            'M_RED': ['#D03030', '#C03030', '#600000', ],
+            'M_RED1': ['#902020', '#802020', '#A00000', ],
+            'M_RED2': ['#701818', '#802020', '#E00000', ],
+            'M_YELLOW': ['#D0D000', '#D0D000', '#606000', ],
+            'M_YELLOW1': ['#909000', '#808000', '#909000', ],
+            'M_YELLOW2': ['#707000', '#A0A000', '#C0C000', ],
+            'M_GREEN': ['#00C000', '#00C000', '#006000', ],
+            'M_GREEN1': ['#008000', '#008000', '#009000', ],
+            'M_GREEN2': ['#005000', '#00A000', '#00C000', ],
             'M_PINK': ['#FF00FF', '#C000C0', '#E000E0', ],
             'M_PINK1': ['#B000B0', '#900090', '#900090', ],
+            'M_CYAN': ['#00FFFF', '#00FFFF', '#00FFFF', ],
+            'M_CYAN1': ['#00B0B0', '#00B0B0', '#00B0B0', ],
             'checkmark': ['checkmark0', 'checkmark1', 'checkmark2', ],
             'arrow-up': ['arrow-up0', 'arrow-up1', 'arrow-up2', ],
             'arrow-down': ['arrow-down0', 'arrow-down1', 'arrow-down2', ],
+            'radio': ['radio0', 'radio1', 'radio2', ],
         }
 
         self.MAC_STYLE = """
@@ -65,16 +70,15 @@ class Styles:
             font-weight: normal;
             font-size: 30pt;
         }
-        QGroupBox[large] {
-            font-family: Arial;
-            font-weight: bold;
-            font-size: 13pt;
-        }
         QGroupBox {
             font-family: Arial;
             font-weight: normal;
             font-size: 11pt;
         }
+        QGroupBox[large] {
+            font-weight: bold;
+            font-size: 13pt;
+        }
         QTextBrowser {
             font-family: Courier New;
             font-weight: bold;
@@ -107,16 +111,15 @@ class Styles:
             font-weight: bold;
             font-size: 20pt;
         }
-        QGroupBox[large] {
-            font-family: Arial;
-            font-weight: normal;
-            font-size: 10pt;
-        }
         QGroupBox {
             font-family: Arial;
             font-weight: normal;
             font-size: 8pt;
         }
+        QGroupBox[large] {
+            font-weight: bold;
+            font-size: 10pt;
+        }
         QTextBrowser {
             font-family: Courier New;
             font-weight: bold;
@@ -199,7 +202,6 @@ class Styles:
         }
         QLineEdit:disabled {
             background-color: $M_GREY1$;
-            color: $M_BLUE$;
         }
         QLineEdit[keypad] {
             background-color: $M_BACK$;
@@ -208,53 +210,27 @@ class Styles:
             border-color: $M_BACK$;
         }
         QLineEdit[input='true']{
-            background-color: $M_BLACK$;
-            border-color: $M_BLUE1$;
+            border-width: 1px;
+            border-color: $M_GREY$;
             border-style: outset;
         }
         QLineEdit[color='green'] {
-            border-width: 2px;
+            border-width: 1px;
             border-style: outset;
             border-color: $M_GREEN$;
         }
         QLineEdit[color='yellow'] {
-            border-width: 2px;
+            border-width: 1px;
             border-style: outset;
             border-color: $M_YELLOW$;
         }
         QLineEdit[color='red'] {
-            border-width: 2px;
+            border-width: 1px;
             border-style: outset;
             border-color: $M_RED$;
         }
-        QLineEdit[char='green'] {
-            color: $M_GREEN$;
-        }
-        QLineEdit[char='yellow'] {
-            color: $M_YELLOW$;
-        }
-        QLineEdit[char='red'] {
-            color: $M_RED$;
-        }
-        QLineEdit[color='red'] {
-            border-width: 2px;
-            border-style: outset;
-            border-color: $M_RED$;
-        }
-        QLineEdit[color='yellow'] {
-            border-width: 2px;
-            border-style: outset;
-            border-color: $M_YELLOW$;
-        }
-        QLineEdit[color='green'] {
-            border-width: 2px;
-            border-style: outset;
-            border-color: $M_GREEN$;
-        }
         QLineEdit[status='on'] {
-            color: $M_BLACK$;
-            border-width: 2px;
-            background-color: $M_BLUE$;
+            color: $M_WHITE$;
         }
         QLabel[color='green'] {
             color: $M_GREEN$;
@@ -281,36 +257,42 @@ class Styles:
             color: $M_WHITE$;
             background-color: $M_BACK$;
         }
-        QGroupBox::title[large='true'] {
+        QGroupBox::title[large=true] {
             left: 5px;
             subcontrol-origin: margin;
             subcontrol-position: top left;
             color: $M_BLUE$;
             background-color: $M_BACK$;
         }
-        QGroupBox::title[refraction='true']{
+        QGroupBox::title[refraction=true]{
             color: $M_BLUE$;
         }
-        QGroupBox[refraction='true'] {
-            border-width: 2px;
+        QGroupBox[refraction=true] {
             border-color: $M_BLUE$;
         }
         QGroupBox:disabled{
-            border-width: 2px;
             border-color: $M_RED$;
         }
-        QGroupBox::title:disabled{
-            color: $M_BLUE1$;
+        QGroupBox::indicator:disabled {
+            border-color: $M_GREY$;
+            background-color: $M_BACK$;
         }
-        QGroupBox[frameless='true'] {
+        QGroupBox::indicator:unchecked {
+            border-color: $M_GREY$;
+            background-color: $M_BACK$;
+        }
+        QGroupBox::title:disabled{
+            color: $M_GREY$;
+        }
+        QGroupBox[frameless=true] {
             border-width: 0px;
         }
-        QGroupBox[frameless='true']:disabled {
+        QGroupBox[frameless=true]:disabled {
             border-width: 2px;
             border-color: $M_RED$;
         }
         QGroupBox::indicator {
-            border-width: 1px;
+            border-width: 2px;
             border-color: $M_GREY$;
             background-color: $M_BACK$;
             border-style: outset;
@@ -319,21 +301,23 @@ class Styles:
             height: 13px;
         }
         QGroupBox::indicator:checked {
-            background-color: $M_BLUE$;
+            border-width: 1px;
+            border-color: $M_BLUE$;
+            background-color: $M_BLUE2$;
             image: url(:/icon/$checkmark$.svg);
         }
-        QGroupBox[running='true'] {
+        QGroupBox[running=true] {
             color: $M_WHITE$;
             border-color: $M_YELLOW$;
             background-color: $M_GREY1$;
         }
-        QGroupBox:title[running='true'] {
+        QGroupBox:title[running=true] {
             color: $M_WHITE$;
         }
         /* Checkboxes */
         QCheckBox {
             color: $M_WHITE$;
-            spacing: 8px;
+            spacing: 5px;
             background-color: $M_TRANS$;;
         }
         QCheckBox::indicator {
@@ -346,18 +330,21 @@ class Styles:
             height: 13px;
         }
         QCheckBox::indicator:checked {
-            background-color: $M_BLUE$;
+            border-width: 1px;
+            border-color: $M_BLUE$;
+            background-color: $M_BLUE2$;
             image: url(:/icon/$checkmark$.svg);
         }
         QCheckBox::indicator:disabled {
-            background-color: $M_TRANS$;;
-            image: None;
+            background-color: $M_BACK$;
+            border-color: $M_GREY$;
         }
         QCheckBox:disabled {
             color: $M_GREY$;
         }
         QRadioButton {
             color: $M_WHITE$;
+            spacing: 5px;
             background-color: $M_TRANS$;;
         }
         QRadioButton:disabled {
@@ -365,17 +352,22 @@ class Styles:
             background-color: $M_TRANS$;;
         }
         QRadioButton::indicator {
-            border-width: 1px;
+            border-width: 2px;
             border-color: $M_GREY$;
             background-color: $M_BACK$;
             border-style: outset;
-            border-radius: 2px;
+            border-radius: 7px;
             width: 13px;
             height: 13px;
         }
         QRadioButton::indicator:checked {
-            background-color: $M_BLUE$;
-            image: url(:/icon/$checkmark$.svg);
+            border-color: $M_BLUE$;
+            background-color: $M_BLUE2$;
+            image: url(:/icon/$radio$.svg);
+        }
+        QRadioButton::indicator:disabled {
+            background-color: $M_BACK$;
+            border-color: $M_GREY$;
         }
         /* Spin Boxes */
         QDoubleSpinBox {
@@ -479,30 +471,21 @@ class Styles:
             border-color: $M_BLUE$;
             border-radius: 8px;
             border-width: 2px;
-            border-style: solid;
+            border-style: outset;
             font-weight: bold;
             font-size: 12px;
         }
-        QPushButton[alignLeft='true'] {
+        QPushButton[alignLeft=true] {
             text-align: left;
             padding-left: 3px;
             padding-right: 3px;
         }
         QPushButton:pressed {
             background-color: $M_BLUE$;
-            color: $M_BLACK$;
         }
-        QPushButton[running='true'] {
-            background-color: $M_BLUE$;
-            color: $M_BLACK$;
-        }
-        QPushButton[pause='true'] {
-            background-color: $M_YELLOW$;
-            color: $M_BLACK$;
-        }
-        QPushButton[cancel='true'] {
-            background-color: $M_RED$;
-            color: $M_WHITE$;
+        QPushButton[running=true] {
+            border-color: $M_BLUE$;
+            background-color: $M_BLUE2$;
         }
         QPushButton:disabled {
             background-color: $M_BACK$;
@@ -517,21 +500,31 @@ class Styles:
             color: $M_BLACK$;
         }
         QPushButton[color='red'] {
-            background-color: $M_RED$;
-            color: $M_BLACK$;
+            border-color: $M_RED$;
+            background-color: $M_RED2$;
+            color: $M_WHITE$;
         }
         QPushButton[color='yellow'] {
-            background-color: $M_YELLOW$;
-            color: $M_BLACK$;
+            background-color: $M_YELLOW2$;
+            border-color: $M_YELLOW$;
+            color: $M_WHITE$;
         }
         QPushButton[color='green'] {
-            background-color: $M_GREEN$;
-            color: $M_BLACK$;
+            background-color: $M_GREEN2$;
+            border-color: $M_GREEN$;
+            color: $M_WHITE$;
         }
-        QPushButton[stop='true'] {
-            background-color: $M_TRANS$;
-            color: $M_TRANS$;
-            border-color: $M_TRANS$;
+        QPushButton:disabled {
+            background-color: $M_BACK$;
+            color: $M_GREY$;
+            border-color: $M_GREY1$;
+            border-width: 1px;
+            border-style: outset;
+            border-radius: 2px;
+        }
+        QPushButton[stop=true] {
+            color: $M_RED2$;
+            border-color: $M_RED$;
         }
         QMessageBox QPushButton {
             background-color: $M_GREY1$;
@@ -595,6 +588,13 @@ class Styles:
             padding-left: 5px;
             background-color: $M_GREY1$;
         }
+        QComboBox:disabled {
+            color: $M_GREY$;
+        }
+        QComboBox[active=true] {
+            border-color: $M_GREEN$;
+            background-color: $M_GREEN2$;
+        }
         QComboBox::drop-down {
             subcontrol-origin: border;
             subcontrol-position: right;
@@ -605,6 +605,9 @@ class Styles:
             border-radius: 2px;
             background-color: $M_GREY1$;
         }
+        QComboBox[active=true]::drop-down {
+            border-color: $M_GREEN$;
+        }
         QComboBox::down-arrow {
             image: url(:/icon/$arrow-down$.svg);
             width: 16px;
@@ -620,15 +623,13 @@ class Styles:
             min-height: 60px;
         }
         QComboBox QListView::item {
+            border-width: 1px;
             min-height: 28px;
+            border-color: $M_BLUE$;
         }
         QComboBox QListView::item:selected {
-            border-width: 1px;
             border-style: outset;
-            border-color: $M_GREY$;
-            border-radius: 2px;
-            color: $M_BACK$;
-            background-color: $M_BLUE$;
+            background-color: $M_BLUE2$;
         }
         /* lines */
         QFrame[frameShape="4"] {
@@ -641,8 +642,10 @@ class Styles:
         QTabWidget:pane {
             border-width: 2px;
             border-color: $M_GREY$;
-            border-radius: 2px;
+            border-radius: 5px;
             border-style: outset;
+            top: -10px;
+            padding-top: 10px;
         }
         /* needed for MAC OSX */
         QTabWidget:tab-bar {
@@ -651,17 +654,16 @@ class Styles:
         QTabBar::tab {
             background-color: $M_GREY1$;
             color: $M_WHITE$;
-            border-width: 2px;
-            border-color: $M_BLUE1$;
+            border-width: 1px;
+            border-color: $M_BLUE2$;
             border-radius: 3px;
             border-style: outset;
             padding: 4px;
-            padding-left: 4px;
-            padding-right: 4px;
         }
         QTabBar::tab:selected {
-            color: $M_BLACK$;
-            background: $M_BLUE$;
+            background: $M_BLUE2$;
+            border-color: $M_BLUE$;
+            border-width: 2px;
         }
         QTabBar::tab:!selected {
             margin-top: 2px;
@@ -672,10 +674,6 @@ class Styles:
         QTabBar::tab:disabled {
             color: $M_GREY$;
             border-color: $M_GREY1$;
-            width: 0;
-            height: 0;
-            padding: 0;
-            border: none;
         }
         /* slider */
         QSlider
@@ -886,6 +884,10 @@ class Styles:
     def M_RED1(self):
         return self.cs['M_RED1'][self.colorSet]
 
+    @property
+    def M_RED2(self):
+        return self.cs['M_RED2'][self.colorSet]
+
     @property
     def M_YELLOW(self):
         return self.cs['M_YELLOW'][self.colorSet]
@@ -894,6 +896,10 @@ class Styles:
     def M_YELLOW1(self):
         return self.cs['M_YELLOW1'][self.colorSet]
 
+    @property
+    def M_YELLOW2(self):
+        return self.cs['M_YELLOW2'][self.colorSet]
+
     @property
     def M_GREEN(self):
         return self.cs['M_GREEN'][self.colorSet]
@@ -902,6 +908,10 @@ class Styles:
     def M_GREEN1(self):
         return self.cs['M_GREEN1'][self.colorSet]
 
+    @property
+    def M_GREEN2(self):
+        return self.cs['M_GREEN2'][self.colorSet]
+
     @property
     def M_PINK(self):
         return self.cs['M_PINK'][self.colorSet]
@@ -910,6 +920,14 @@ class Styles:
     def M_PINK1(self):
         return self.cs['M_PINK1'][self.colorSet]
 
+    @property
+    def M_CYAN(self):
+        return self.cs['M_CYAN'][self.colorSet]
+
+    @property
+    def M_CYAN1(self):
+        return self.cs['M_CYAN1'][self.colorSet]
+
     @property
     def mw4Style(self):
         if platform.system() == 'Darwin':
