@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -32,7 +31,7 @@ class CameraAlpaca(AlpacaClass, CameraSupport):
     __all__ = ['CameraAlpaca']
 
     def __init__(self, app=None, signals=None, data=None, parent=None):
-        super().__init__(app=app, data=data, threadPool=app.threadPool)
+        super().__init__(app=app, data=data)
         self.signals = signals
         self.data = data
         self.abortExpose = False
@@ -94,7 +93,7 @@ class CameraAlpaca(AlpacaClass, CameraSupport):
             self.setAlpacaProperty('fastreadout', FastReadout=True)
 
         quality = 'High' if self.data.get('READOUT_QUALITY.QUALITY_HIGH', True) else 'Low'
-        self.log.debug(f'Camera has readout quality entry: {quality}')
+        self.log.info(f'Camera has readout quality entry: {quality}')
         return True
 
     def workerExpose(self,
@@ -130,7 +129,9 @@ class CameraAlpaca(AlpacaClass, CameraSupport):
 
         self.setAlpacaProperty('startexposure', Duration=expTime, Light=True)
         self.waitExposed(self.getAlpacaProperty, 'imageready', expTime)
+        self.signals.exposed.emit()
         data = self.retrieveFits(self.getAlpacaProperty, 'imagearray')
+        self.signals.downloaded.emit()
         imagePath = self.saveFits(imagePath, data, expTime, binning, focalLength)
         self.signals.saved.emit(imagePath)
         self.signals.exposeReady.emit()
