@@ -10,8 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
-#
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -24,7 +23,8 @@ import csv
 
 # external packages
 import numpy as np
-import skyfield.api
+from skyfield.api import Star
+from skyfield import almanac
 from scipy.spatial import distance
 
 # local imports
@@ -91,13 +91,13 @@ class DataPoint(object):
 
     STEP_N = {'min': [15, -15, 15, -15, 15, -30, 30],
               'norm': [10, -10, 10, -10, 10, -20, 20],
-              'med': [10, -10, 10, -10, 10, -20, 20, -30, 30],
+              'med': [10, -10, 10, -10, 10, -15, 15, -20, 20],
               'max': [10, -10, 10, -10, 10, -10, 10, -20, 20, -30, 30],
               }
 
     STEP_S = {'min': [30, -30, 15, -15, 15, -15, 15],
               'norm': [20, -20, 10, -10, 10, -10, 10],
-              'med': [30, -30, 20, -20, 10, -10, 10, -10, 10],
+              'med': [20, -20, 15, -15, 10, -10, 10, -10, 10],
               'max': [30, -30, 20, -20, 10, -10, 10, -10, 10, -10, 10],
               }
     START = {'min': [-120, -5, -120, -5, -120, -5, -120,
@@ -119,10 +119,7 @@ class DataPoint(object):
                     120, 0, 120, 0, 120, 0, 120, 0, 120, 0, 120, 0],
             }
 
-    def __init__(self,
-                 app=None,
-                 ):
-
+    def __init__(self, app=None):
         self.app = app
         self.configDir = app.mwGlob['configDir']
         self._horizonP = list()
@@ -353,7 +350,7 @@ class DataPoint(object):
     def isCloseMeridian(self, point):
         """
         isCloseMeridian check if a point is close to meridian slew / track
-        limits limit
+        limits
 
         :param point:
         :return: status
@@ -434,23 +431,41 @@ class DataPoint(object):
 
         return True
 
-    def loadJSON(self, fileName, ext):
+    def loadModel(self, fullFileName):
         """
-        :param fileName: name of file to be handled
-        :param ext: extension of file to be handled
+        :param fullFileName: name of file to be handled
         :return: value: loaded data
         """
-        fileName = self.configDir + '/' + fileName + ext
-
-        if not os.path.isfile(fileName):
+        if not os.path.isfile(fullFileName):
             return None
 
         try:
-            with open(fileName, 'r') as handle:
+            with open(fullFileName, 'r') as handle:
                 value = json.load(handle)
 
         except Exception as e:
-            self.log.info('Cannot BPTS load: {0}, error: {1}'.format(fileName, e))
+            self.log.info('Cannot Model load: {0}, error: {1}'.format(fullFileName, e))
+            value = None
+
+        else:
+            value = [(x['altitude'], x['azimuth']) for x in value]
+
+        return value
+
+    def loadJSON(self, fullFileName):
+        """
+        :param fullFileName: name of file to be handled
+        :return: value: loaded data
+        """
+        if not os.path.isfile(fullFileName):
+            return None
+
+        try:
+            with open(fullFileName, 'r') as handle:
+                value = json.load(handle)
+
+        except Exception as e:
+            self.log.info('Cannot BPTS load: {0}, error: {1}'.format(fullFileName, e))
             value = None
 
         else:
@@ -458,17 +473,15 @@ class DataPoint(object):
 
         return value
 
-    def loadCSV(self, fileName, ext):
+    def loadCSV(self, fullFileName):
         """
-        :param fileName: name of file to be handled
-        :param ext: extension of file to be handled
+        :param fullFileName: name of file to be handled
         :return: value: loaded data
         """
-        fileName = self.configDir + '/' + fileName + ext
-        if not os.path.isfile(fileName):
+        if not os.path.isfile(fullFileName):
             return None
 
-        with open(fileName, 'r') as handle:
+        with open(fullFileName, 'r') as handle:
             testLine = handle.readline()
 
         if ';' in testLine:
@@ -478,13 +491,13 @@ class DataPoint(object):
 
         try:
             value = []
-            with open(fileName, 'r', encoding='utf-8-sig') as csvFile:
+            with open(fullFileName, 'r', encoding='utf-8-sig') as csvFile:
                 reader = csv.reader(csvFile, delimiter=delimiter)
                 for row in reader:
                     value.append(tuple(float(val) for val in row))
 
         except Exception as e:
-            self.log.info('Cannot CSV load: {0}, error: {1}'.format(fileName, e))
+            self.log.info('Cannot CSV load: {0}, error: {1}'.format(fullFileName, e))
             return None
 
         else:
@@ -503,24 +516,26 @@ class DataPoint(object):
 
         return True
 
-    def loadBuildP(self, fileName=None, ext='.bpts', keep=False):
+    def loadBuildP(self, fullFileName=None, ext='.bpts', keep=False):
         """
         loadBuildP loads a modeldata pints file and stores the data in the
         buildP list. necessary conversion are made.
 
-        :param fileName: name of file to be handled
+        :param fullFileName: name of file to be handled
         :param ext: load extension type
         :param keep:
         :return: success
         """
-        if fileName is None:
+        if fullFileName is None:
             return False
 
         value = None
         if ext == '.csv':
-            value = self.loadCSV(fileName, ext)
+            value = self.loadCSV(fullFileName)
         elif ext == '.bpts':
-            value = self.loadJSON(fileName, ext)
+            value = self.loadJSON(fullFileName)
+        elif ext == '.model':
+            value = self.loadModel(fullFileName)
 
         if value is None:
             return False
@@ -530,7 +545,7 @@ class DataPoint(object):
             self.clearBuildP()
             return False
 
-        points = [(x[0], x[1], True) for x in value]
+        points = [(x[0], x[1], 1) for x in value]
 
         if keep:
             self._buildP += points
@@ -538,7 +553,8 @@ class DataPoint(object):
             self._buildP = points
 
         # backup solution
-        if csv:
+        if ext in ['.csv', '.model']:
+            fileName = os.path.basename(fullFileName).split('.')[0]
             self.saveBuildP(fileName=fileName)
 
         return True
@@ -574,11 +590,12 @@ class DataPoint(object):
         if fileName is None:
             return False
 
+        fullFileName = self.configDir + '/' + fileName + ext
         value = None
         if ext == '.csv':
-            value = self.loadCSV(fileName, ext)
+            value = self.loadCSV(fullFileName)
         elif ext == '.hpts':
-            value = self.loadJSON(fileName, ext)
+            value = self.loadJSON(fullFileName)
 
         suc = self.checkFormat(value)
         if not suc:
@@ -607,9 +624,7 @@ class DataPoint(object):
         fileName = self.configDir + '/' + fileName + '.hpts'
 
         with open(fileName, 'w') as handle:
-            json.dump(self.horizonP,
-                      handle,
-                      indent=4)
+            json.dump(self.horizonP, handle, indent=4)
 
         return True
 
@@ -667,12 +682,10 @@ class DataPoint(object):
         for dec, step, start, stop in self.genHaDecParams(selection, lat):
             for ha in range(start, stop, step):
                 alt, az = HaDecToAltAz(ha / 10, dec, lat)
+
                 # only values with above horizon = 0
-
                 if 5 <= alt <= 85 and 2 < az < 358:
-                    alt += random.uniform(-2, 2)
-                    self.addBuildP((alt, az, True))
-
+                    self.addBuildP((alt, az, 1))
         return True
 
     @staticmethod
@@ -691,18 +704,18 @@ class DataPoint(object):
         for i, alt in enumerate(eastAlt):
             if i % 2:
                 for az in range(minAz, 180, stepAz):
-                    yield(alt, az, True)
+                    yield (alt, az, 1)
             else:
                 for az in range(180 - minAz, 0, -stepAz):
-                    yield(alt, az, True)
+                    yield (alt, az, 1)
 
         for i, alt in enumerate(westAlt):
             if i % 2:
                 for az in range(180 + minAz, 360, stepAz):
-                    yield(alt, az, True)
+                    yield (alt, az, 1)
             else:
                 for az in range(maxAz, 180, -stepAz):
-                    yield(alt, az, True)
+                    yield (alt, az, 1)
 
     def genGrid(self, minAlt=5, maxAlt=85, numbRows=5, numbCols=6, keep=False):
         """
@@ -786,7 +799,7 @@ class DataPoint(object):
 
         for i in range(0, numberBase):
             az = azBase + i * stepAz
-            self.addBuildP((altBase, az % 360, True))
+            self.addBuildP((altBase, az % 360, 1))
 
         return True
 
@@ -805,40 +818,55 @@ class DataPoint(object):
 
         for dec in range(-75, 90, 15):
             for ha in range(- 119, 120, 2):
-                az, alt = HaDecToAltAz(ha / 10, dec, lat)
+                alt, az = HaDecToAltAz(ha / 10, dec, lat)
                 if alt > 0:
-                    celestialEquator.append((az, alt))
+                    celestialEquator.append((alt, az))
 
         for ha in range(-115, 120, 10):
             for dec in range(- 90, 90, 2):
-                az, alt = HaDecToAltAz(ha / 10, dec, lat)
+                alt, az = HaDecToAltAz(ha / 10, dec, lat)
                 if alt > 0:
-                    celestialEquator.append((az, alt))
+                    celestialEquator.append((alt, az))
 
         return celestialEquator
 
-    def generateDSOPath(self, ra=0, dec=0, timeJD=0, location=None,
-                        numberPoints=0, duration=0, timeShift=0, keep=False):
+    @staticmethod
+    def calcPath(ts, numberPoints, edgeDSO, ha, dec, location):
+        """
+        :param ts:
+        :param numberPoints:
+        :param edgeDSO:
+        :param ha:
+        :param dec:
+        :param location:
+        :return:
+        """
+        buildP = []
+        for i in range(numberPoints):
+            starTime = ts.tt_jd(edgeDSO + i / numberPoints)
+            az, alt = transform.J2000ToAltAz(ha, dec, starTime, location)
+            if alt.degrees > 0:
+                buildP.append((alt.degrees, az.degrees % 360, 1))
+        return buildP
+
+    def generateDSOPath(self, ha=0, dec=0, timeJD=0, location=None,
+                        numberPoints=0, keep=False):
         """
         generateDSOPath calculates a list of model points along the desired path
         beginning at ra, dec coordinates, which is in time duration hours long
         and consists of numberPoints model points. TimeShift moves the pearl of
         points to an earlier or later point in time.
 
-        :param ra:
+        :param ha:
         :param dec:
         :param timeJD:
         :param location:
         :param numberPoints:
-        :param duration:
-        :param timeShift:
         :param keep:
         :return: True for test purpose
         """
         if numberPoints < 1:
             return False
-        if duration == 0:
-            return False
         if location is None:
             return False
 
@@ -846,13 +874,28 @@ class DataPoint(object):
         if not keep:
             self.clearBuildP()
 
-        for i in range(0, numberPoints):
-            startPoint = ra.hours - i * duration / numberPoints - timeShift
-            raCalc = skyfield.api.Angle(hours=startPoint)
-            az, alt = transform.J2000ToAltAz(raCalc, dec, timeJD, location)
-            if alt.degrees > 0:
-                self.addBuildP((alt.degrees, az.degrees % 360, True))
+        star = Star(ra=ha, dec=dec)
+        startTime = timeJD
+        ts = self.app.mount.obsSite.ts
+        endTime = ts.tt_jd(timeJD.tt + 1.1)
+        eph = self.app.ephemeris
+        f = almanac.risings_and_settings(eph, star, location)
+        f.step_days = 0.08
+        t, y = almanac.find_discrete(startTime, endTime, f)
 
+        index = next((x for x in y if x == 1), None)
+        if index is None:
+            edgeDSO = int(ts.now().tt) - 0.5
+        else:
+            edgeDSO = t[index].tt
+
+        number = numberPoints
+        buildPs = []
+        while len(buildPs) < numberPoints:
+            buildPs = self.calcPath(ts, number, edgeDSO, ha, dec, location)
+            number += 1
+        for buildP in buildPs:
+            self.addBuildP(buildP)
         return True
 
     def generateGoldenSpiral(self, numberPoints, keep=False):
@@ -867,8 +910,6 @@ class DataPoint(object):
         :param keep:
         :return: true for test purpose
         """
-        if numberPoints < 50:
-            return False
         if not keep:
             self.clearBuildP()
 
@@ -881,6 +922,18 @@ class DataPoint(object):
 
         for alt, az in zip(altitude, azimuth):
             if alt > 0:
-                self.addBuildP((alt, az, True))
+                self.addBuildP((alt, az, 1))
 
         return True
+
+    def ditherPoints(self):
+        """
+        :return:
+        """
+        for i, point in enumerate(self.buildP):
+            alt = point[0]
+            az = point[1]
+            alt += random.uniform(-1, 1)
+            az += random.uniform(-1, 1)
+            self.buildP[i] = (alt, az, 1)
+        return True
