@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -29,10 +29,8 @@ class TelescopeAscom(AscomClass):
     __all__ = ['TelescopeAscom']
 
     def __init__(self, app=None, signals=None, data=None):
-        super().__init__(app=app, data=data, threadPool=app.threadPool)
-
+        super().__init__(app=app, data=data)
         self.signals = signals
-        self.data = data
 
     def workerGetInitialConfig(self):
         """
