@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2022 by mworion
+# written in python3, (c) 2019-2023 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -71,6 +71,7 @@ class Setting(object):
         self._weatherTemperature = None
         self._weatherHumidity = None
         self._weatherDewPoint = None
+        self._weatherAge = None
         self._trackingRate = None
         self._webInterfaceStat = None
 
@@ -309,6 +310,14 @@ class Setting(object):
     def weatherDewPoint(self, value):
         self._weatherDewPoint = valueToFloat(value)
 
+    @property
+    def weatherAge(self):
+        return self._weatherAge
+
+    @weatherAge.setter
+    def weatherAge(self, value):
+        self._weatherAge = valueToInt(value)
+
     @property
     def trackingRate(self):
         return self._trackingRate
@@ -363,6 +372,10 @@ class Setting(object):
         self.addressLanMAC = response[14]
         self.wakeOnLan = response[15]
         self.weatherStatus = response[16]
+        if len(response[17].split(',')) > 1:
+            self.weatherAge = response[17].split(',')[1]
+        else:
+            self.weatherAge = ''
         self.weatherPressure = response[17].split(',')[0]
         self.weatherTemperature = response[18].split(',')[0]
         self.weatherHumidity = response[19].split(',')[0]
@@ -410,7 +423,7 @@ class Setting(object):
         suc, response, numberOfChunks = conn.communicate(commandString)
         if not suc:
             return False
-        if response[0] != '1':
+        if response[0] != '10':
             return False
         return True
 
@@ -421,7 +434,7 @@ class Setting(object):
         :return: success
         """
         conn = Connection(self.host)
-        commandString = ':RS#'
+        commandString = ':RC3#'
         suc, response, numberOfChunks = conn.communicate(commandString)
         return suc
 
@@ -435,7 +448,7 @@ class Setting(object):
         :return: success
         """
         conn = Connection(self.host)
-        commandString = ':RC2#:RC#'
+        commandString = ':RC2#'
         suc, response, numberOfChunks = conn.communicate(commandString)
         return suc
 
@@ -450,7 +463,7 @@ class Setting(object):
         """
         conn = Connection(self.host)
         centerSpeed = 255
-        commandString = f':Rc{centerSpeed:02.0f}#:RC#'
+        commandString = f':Rc{centerSpeed:02.0f}#'
         suc, response, numberOfChunks = conn.communicate(commandString)
         return suc
 
@@ -465,7 +478,7 @@ class Setting(object):
         """
         conn = Connection(self.host)
         centerSpeed = 128
-        commandString = f':Rc{centerSpeed:02.0f}#:RC#'
+        commandString = f':Rc{centerSpeed:02.0f}#'
         suc, response, numberOfChunks = conn.communicate(commandString)
         return suc
 
